/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit;

import de.fhstralsund.catsit.base.MetastaseException;
import de.fhstralsund.catsit.io.excel.merger.ExcelMerger;
import de.fhstralsund.catsit.io.excel.merger.ExcelMergerException;
import de.fhstralsund.catsit.machine.SimController;

/**
 * Main class for executable jar that decides between SimController and ExcelMerger based on the first argument.
 * 
 * @author Anja Bethge
 *
 */
public class CaTSiT {
	
	private static final String USAGE_STRING = "usage:\n"
												+ "java -jar CaTSiT.jar simulate excelFile excelSheetName configFile technicalFile\n"
												+ "or \n"
												+ "java -jar CaTSiT.jar merge destinationFile sourceFile\n"
												+ "or \n"
												+ "java -jar CaTSiT.jar zip destinationFile\n";
    
	public static void main( String[] args ) throws MetastaseException, ExcelMergerException{
		
		try {
			if(args.length == 0){
				throw new WrongArgumentsException("No arguments stated.\n"+ USAGE_STRING);
			}		
			
	    	String[] newArgs = new String[args.length-1];
	    	for (int i = 0; i < args.length-1; i++) {
				newArgs[i] = args[i+1];
			}
	    	
	    	if(args[0].equals("simulate")){
	    		new SimController(newArgs);
	    		
	    	}else if (args[0].equals("merge") || args[0].equals("zip")){
	    		new ExcelMerger(newArgs);
	    		
	    	}else{
	    		throw new WrongArgumentsException("Unknown argument '"+args[0]+"'. Only 'simulate', 'merge' or 'zip' are allowed as first argument.\n"+ USAGE_STRING);
	    	}
	    	
		} catch (WrongArgumentsException e) {
			System.err.println(e.getMessage());
			System.exit(1);
		}
		
    }
}
