/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base;

/**
 * Base class for all Events
 * @author Gero Wedemann, Anja Bethge
 *
 */

public abstract class Event {
	
	private double time;
	
	public Event(double time){
		this.time = time;		
	}
	
	public double getTime() {
		return time;
	}
		
	public abstract void execute() throws MetastaseException;

	//////////// equals() & hashCode() ////////////////////////////////////////////////////////////////////////////////////////////////////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////   	
	@Override
	public int hashCode() {
		final int prime = 74;
		int result = 1;
		long temp;
		temp = Double.doubleToLongBits(time);
		result = prime * result + (int) (temp ^ (temp >>> 32));
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj) return true;
		if (obj == null) return false;
		if (getClass() != obj.getClass()) return false;

		return (time == ((Event) obj).time);
	}
	
	/**
	 * Is only used by the EventList (Hedriksen)  
	 * @param obj
	 * @return true, if the given object is the same as this one. false if not (e.g. the given object is equal to this object, but not the same)
	 */
	public boolean sameAs(Object obj) {
		return(this == obj);
	}
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////   

}
