/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base;

import de.fhstralsund.catsit.base.eventactions.globaleventactions.GlobalEventAction;

/**
 * A global event can influences/changes more than one compartment
 * E.g. radionuclide therapy or chemo therapy
 * 
 * @author Anja Bethge
 *
 */
public class GlobalEvent extends Event {

	//the event action that shall be executed
	private GlobalEventAction eventAction;
	
	/**
	 * 
	 * @param action the action that will be executed on the compartment
	 * @param time the time, event will occur
	 */
	public GlobalEvent(GlobalEventAction action, double time) {
		super(time);
		this.eventAction = action;
	}
	
	public GlobalEventAction getEventAction(){
		return eventAction;
	}
	
	@Override
	public void execute() throws MetastaseException{
		eventAction.execute(getTime());
	}

	
	//////////// toString(), equals() & hashCode() ////////////////////////////////////////////////////////////////////////////////////////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////   
	@Override
	public String toString() {
		return "GlobalEvent [time=" + getTime() + ", eventAction=" + eventAction + "]";
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = super.hashCode();
		result = prime * result	+ ((eventAction == null) ? 0 : eventAction.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj) return true;
		if (!super.equals(obj)) return false;
		
		GlobalEvent other = (GlobalEvent) obj;
		
		return ((eventAction == null)? other.eventAction == null : eventAction.equals(other.eventAction));
	}
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////   

}
