/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base;

import de.fhstralsund.catsit.base.eventactions.localeventactions.LocalEventAction;

/**
 * A local event can influences/changes only one single compartment 
 * and has no further effect on the rest of the compartments. E.g. cell devision,
 * cell death or creation of a new metastasis
 * 
 * @author Anja Bethge
 *
 */
public class LocalEvent extends Event{

	//the event action that shall be executed
	private LocalEventAction eventAction;
	
	//the compartment that is influenced by the execution of the event action
	private Compartment compartment;
	
	/**
	 * 
	 * @param action the action that will be executed on the compartment
	 * @param time the time, event will occur
	 * @param compartment the compartment that will be influenced by the event
	 */
	public LocalEvent(LocalEventAction action, double time, Compartment compartment) {
		super(time);
		this.eventAction = action;
		this.compartment = compartment;
	}
	

	public Compartment getCompartment() {
		return compartment;
	}
	
	public LocalEventAction getEventAction(){
		return eventAction;
	}
	
	public void execute() throws MetastaseException{
		eventAction.execute(compartment, getTime());	
	}
	
	//////////// toString(), equals() & hashCode() ////////////////////////////////////////////////////////////////////////////////////////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////   
	@Override
	public String toString() {
		return "LocalEvent [time=" + getTime() + ", eventAction=" + eventAction + ", compartment=" + compartment + "]";
	}


	@Override
	public int hashCode() {
		final int prime = 41;
		int result = super.hashCode();
		result = prime * result	+ ((compartment == null) ? 0 : compartment.hashCode());
		result = prime * result	+ ((eventAction == null) ? 0 : eventAction.hashCode());
		return result;
	}


	@Override
	public boolean equals(Object obj) {
		if (this == obj) return true;
		if (!super.equals(obj))	return false;
		
		LocalEvent other = (LocalEvent) obj;
		
		return (((eventAction == null)? other.eventAction == null : eventAction.equals(other.eventAction))&&
				((compartment == null)? other.compartment == null : compartment.equals(other.compartment)));

	}
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////   	
}
