/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.conditions;

/**
 * The Condition interface provides a function, that allows to check whether the condition is true or not.
 * @author Anja Bethge, Michael Suhr
 *
 */
public abstract class Condition {
	
	public static final int GREATER_EQUALS = 0;
	public static final int LESSER = 1;
	
	private int conditionTest;
	
	/**
	 * 
	 * @param conditionTest the conditions test can be Condition.GREATER_EQUALS or Condition.LESSER
	 */
	public Condition(int conditionTest) {
		this.conditionTest = conditionTest;
	}

	/**
	 * 
	 * @param currentTime the current time
	 * @param size the size (number of cells) of the discrete compartment
	 * @return true, if the given value and the compare value in the corresponding instance fulfill the specified condition test. false, otherwise.
	 */
	public abstract boolean isConditionTrue(double currentTime, long size);
	
	public int getConditionTest() {
		return conditionTest;
	}
	
	/**
	 * 
	 * @param conditionTest the string value of the condition test.
	 * @return Returns the corresponding <code>int</code> value for the conditionTest given as <code>String</code>. Otherwise, -1.
	 */
	public static int valueOf(String conditionTest) {
        if (conditionTest.equals(">=") || conditionTest.equals("GREATER_EQUALS")) {
            return GREATER_EQUALS;
        } else if (conditionTest.equals("<") || conditionTest.equals("LESSER")) {
            return LESSER;
        }
        return -1;
	}

	//////////// equals() & hashCode() ////////////////////////////////////////////////////////////////////////////////////////////////////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	
	@Override
	public int hashCode() {
		final int prime = 52;
		int result = 1;
		result = prime * result + conditionTest;
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj) return true;
		if (obj == null) return false;
		if (getClass() != obj.getClass()) return false;
		
		return (conditionTest == ((Condition) obj).conditionTest);
	}
	
	

}
