/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.conditions;

/**
 * Compares the size.
 * 
 * @author Anja Bethge, Michael Suhr
 * 
 */
public class SizeCondition extends Condition {

	//the size to compare with
    private long compareSize;

    /**
     * 
     * @param conditionTest the conditions test can be Condition.GREATER_EQUALS or Condition.LESSER
     * @param theCompareSize the size to compare with
     */
    public SizeCondition(int conditionTest, long compareSize) {
        super(conditionTest);
        this.compareSize = compareSize;
    }

    @Override
    public boolean isConditionTrue(double currentTime, long size) {
    	
        switch (getConditionTest()) {
        case GREATER_EQUALS:
            return size >= compareSize;
        case LESSER:
            return size < compareSize;
        default:
            return false;
        }
    }

    public long getCompareSize() {
        return this.compareSize;
    }

    
	////////////toString(), equals() & hashCode() ////////////////////////////////////////////////////////////////////////////////////////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

    @Override
    public String toString() {
    	String s = "size";
    	
    	switch (getConditionTest()) {
        case GREATER_EQUALS:
            s+=">=";break;
        case LESSER:
            s+="<";break;
        default:
        	s+="?";
    	}
            
        return s + compareSize;
    }

	@Override
	public int hashCode() {
		final int prime = 91;
		int result = super.hashCode();
		result = prime * result + (int) (compareSize ^ (compareSize >>> 32));
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj) return true;
		if (!super.equals(obj))	return false;
		
		return (compareSize == ((SizeCondition) obj).compareSize);
	}    
}
