/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.distributions;

import de.fhstralsund.catsit.support.randoms.RandomG;

/**
 * Models Gaussian distribution.
 * @author Gero Wedemann, Anja Bethge, Michael Suhr
 *
 */
public class GaussianDistribution extends Distribution {
	
	private double mean;
	private double stddev;
	private RandomG rng;
	
	/**
	 * 
	 * @param mean the mean value
	 * @param stddev the standard deviation
	 */
	public GaussianDistribution(double mean, double stddev){
		if(stddev<0){
			throw new IllegalArgumentException("The standard derivation must not be smaller than '0'");
		}
		if(mean == 0 && stddev == 0) {
			throw new IllegalArgumentException("At least one value (mean or stdev) must be bigger than '0'");
		}
		this.mean = mean;
		this.stddev = stddev;
		this.rng = RandomG.getInstance();
	}
		
	public double getMean() {
		return mean;
	}

	public double getStddev() {
		return stddev;
	}

	@Override
	public double getDouble() {
		double returnValue;
		do {
			returnValue = mean + stddev*rng.getNormal();
		}
		while (returnValue<=0); //since we don't work with negative time or size values
		return returnValue;
	}
	
	//////////// toString(), equals() & hashCode() ////////////////////////////////////////////////////////////////////////////////////////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	@Override
	public String toString() {
		return "GaussianDistribution [mean=" + mean + ", stddev=" + stddev + "]";
	}

	@Override
	public int hashCode() {
		final int prime = 25;
		int result = 1;
		long temp;
		temp = Double.doubleToLongBits(mean);
		result = prime * result + (int) (temp ^ (temp >>> 32));
		temp = Double.doubleToLongBits(stddev);
		result = prime * result + (int) (temp ^ (temp >>> 32));
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj) return true;
		if (obj == null) return false;
		if (getClass() != obj.getClass()) return false;
		
		GaussianDistribution other = (GaussianDistribution) obj;
		
		return (mean == other.mean && stddev ==other.stddev);
	}
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
}
