/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.distributions;

import de.fhstralsund.catsit.support.randoms.RandomG;

/**
 * Models uniform distribution.
 * @author Gero Wedemann, Anja Bethge, Michael Suhr
 *
 */
public class UniformDistribution extends Distribution {
	
	private double min;
	private double interval;
	private RandomG rng;
	
	/**
	 * 
	 * @param min the minimum value of the distribution
	 * @param max the maximum value of the distribution
	 */
	public UniformDistribution(double min, double max) {
		
		if(max<=min){
			throw new IllegalArgumentException("The value of 'max' must not be smaller or euqal than the value of 'min'.");
		}
		
		this.min = min;
		this.interval = max-min;
		
		this.rng = RandomG.getInstance();
	}
	
	
	public double getMin() {
		return min;
	}

	public double getMax() {
		return min + interval;
	}


	@Override
	public double getDouble() {
		return min + rng.getDouble()*interval;
	}

	////////////toString(), equals() & hashCode() ////////////////////////////////////////////////////////////////////////////////////////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	
	@Override
	public String toString() {
		return "UniformDistribution [min=" + min + ", interval=" + interval	+ "]";
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		long temp;
		temp = Double.doubleToLongBits(interval);
		result = prime * result + (int) (temp ^ (temp >>> 32));
		temp = Double.doubleToLongBits(min);
		result = prime * result + (int) (temp ^ (temp >>> 32));
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj) return true;
		if (obj == null) return false;
		if (getClass() != obj.getClass()) return false;
		
		UniformDistribution other = (UniformDistribution) obj;
		
		return (interval == other.interval && min == other.min);
	}
}
