/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.eventactions.globaleventactions;

import java.util.logging.Logger;

import de.fhstralsund.catsit.base.MetastaseException;

/**
 * Abstract base class for global event actions.
 * Global events actions can influence all compartments. The extensions of this class
 * define the actions in the method {@link #execute()} * 
 * 
 * @author Anja Bethge
 * 
 */
public abstract class GlobalEventAction {

	protected static final Logger logger = Logger.getLogger("metastase.base.eventaction");

	private String name;

	/**
	 * 
	 * @param name the name of the event action
	 */
	public GlobalEventAction(String name) {
		this.name = name;
	}

	public String getName() {
		return name;
	}

	public abstract void execute(double currentTime) throws MetastaseException;

	//////////// toString(), equals() & hashCode() ////////////////////////////////////////////////////////////////////////////////////////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

	@Override
	public String toString() {
		return "GlobalEventAction [name=" + name + "]";
	}
	
	@Override
	public int hashCode() {
		final int prime = 14;
		int result = 1;
		result = prime * result + ((name == null) ? 0 : name.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj) return true;
		if (obj == null) return false;
		if (getClass() != obj.getClass()) return false;
		
		GlobalEventAction other = (GlobalEventAction) obj;
		
		return ((name == null) ? other.name == null : name.equals(other.name));
	}
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

}
