/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.eventactions.globaleventactions;

import de.fhstralsund.catsit.base.DiscreteCompartment;

/**
 * Basic Event Action for all therapies that handle radioactive material, such as external beam radiation therapy, 
 * radioimmunotherapy and radioembolisation.
 * @author Anja Bethge
 *
 */
public abstract class RadioTherapy extends GlobalEventAction {

	public RadioTherapy(String name) {
		super(name);
	}

	/**
	 * Resets the number of cells and deletes invalid events from the event list.
	 * @param dc the discrete compartment to handle
	 * @param numberOfCellsAfterTreatment
	 * @param survivalRate
	 */
	protected void handleDiscreteCompartment(DiscreteCompartment dc, long numberOfCellsAfterTreatment, double survivalRate){
		
		if(numberOfCellsAfterTreatment < 1){
			//the tumor is dead, reset the number of cells to zero ...
			dc.setNumberOfCells(0);			
			//... and delete all Events related to this compartment
			dc.deleteEvents(1.0);
			//reset the dormant information (since its dead it isn't dormant anymore)
			dc.setDormant(false);
			dc.setInLateDormancy(false);
		}else{
			//reset the number of cells in the compartment
			dc.setNumberOfCells(numberOfCellsAfterTreatment);
			//delete some of the events related to this compartment, according to the survival rate
			dc.deleteEvents(1-survivalRate);
		}
	}	
}
