/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
*/

package de.fhstralsund.catsit.base.eventactions.localeventactions;

import java.util.logging.Logger;

import de.fhstralsund.catsit.base.Compartment;
import de.fhstralsund.catsit.base.MetastaseException;

/**
 * Abstract base class for local actions. The extensions of this class define the actions in the 
 * method {@link #execute()}
 *        
 * @author Gero Wedemann, Anja Bethge
 *
 */
public abstract class LocalEventAction{
	
	protected static final Logger logger = Logger.getLogger("metastase.base.eventaction");
	
	private String name;
	
	
    /**
     * @param name name of this action
     * @param generationInfo the generation informations for this event action
     */
    public LocalEventAction(String name) {
        this.name = name;
    }

    public String getName() {
        return name;
    }
    
    
    /**
     * Here goes the logic, what happens in an event action. This has to be
     * implemented in derived classes
     * 
     * @param compartment the Compartment where we work
     * @param curentTime needed for calculation of next events
     * @throws MetastaseException, if something goes wrong
     */
    public abstract void execute(Compartment compartment, double currentTime) throws MetastaseException;
    

	@Override
	public int hashCode() {
		final int prime = 5;
		int result = 1;
		result = prime * result + ((name == null) ? 0 : name.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj) return true;
		if (obj == null) return false;
		if (getClass() != obj.getClass()) return false;
		
		LocalEventAction other = (LocalEventAction) obj;
		
		return ((name == null)? other.name == null: name.equals(other.name));
	}    
}
