/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.eventactions.localeventactions;

import de.fhstralsund.catsit.base.Compartment;
import de.fhstralsund.catsit.base.ContinuousCompartment;
import de.fhstralsund.catsit.base.MetastaseException;

/**
 * Switches the compartment into late dormancy state.
 * @author Anja Bethge
 *
 */
public class StartLateDormancy extends LocalEventAction {	
	
	public StartLateDormancy() {
		super("start late dormancy");
	}

	@Override
	public void execute(Compartment compartment, double currentTime) throws MetastaseException {
		
		//only continuous compartments need an event to change into late dormant state
		if(compartment instanceof ContinuousCompartment){
			// we can ignore this event if the compartment is already dead
			if(compartment.getNumberOfCells(currentTime)>=1) compartment.setInLateDormancy(true);
			
		}else{
			throw new IllegalArgumentException("Discrete compartments are not handled by the StartLateDormancy event action.");
		}
		
		//discrete compartments switch into late dormancy state themselves when they reach the corresponding start size 
		//(see method addCell() in DiscreteCompartment)
	}

}
