/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.eventactions.localeventactions;

import de.fhstralsund.catsit.base.DiscreteCompartment;
import de.fhstralsund.catsit.base.MetastaseException;
import de.fhstralsund.catsit.base.eventactions.GenerationInfo;

/**
 * Transfers one cell from a discrete compartment to its successor-compartment.
 * 
 * @author Gero Wedemann, Anja Bethge
 */
public class TransferToNextCompartment extends CellProgressionEventAction {

	/**
	 * @param name name of this action
     * @param generationInfo the generation informations for this event action
	 */
	public TransferToNextCompartment(String name, GenerationInfo generationInfo) {
		super(name, generationInfo);
	}

	@Override
	protected void execute(DiscreteCompartment compartment, double currentTime) throws MetastaseException{
		
		compartment.transferCellToNextCompartment(currentTime);
		compartment.getSuccessor().createNextEvent(currentTime);
	
	}

	@Override
	public String toString() {
		return "TransferToNextCompartment ["+super.toString()+"]";
	}
}
