/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.treatments;


/**
 * Abstract base class for all radiation therapies.
 * 
 * @author Anja Bethge
 *
 */
public abstract class RadiationTreatment extends Treatment{
	
	private double alpha;
	private double beta;

	/**
	 * 
	 * @param alpha radiosensitivity of the cells (probability for a DSB). Unit: 1/Gy
	 * @param beta radiosensitivity of the cells (probability for two SSB that lead to a DSB). Unit: 1/(Gy*Gy)
	 */
	public RadiationTreatment(double alpha, double beta) {
		super();
		this.alpha = alpha;
		this.beta = beta;
	}

	public double getAlpha() {
		return alpha;
	}

	public double getBeta() {
		return beta;
	}
	
	
	
	@Override
	public String toString() {
		return "alpha=" + alpha + ", beta=" + beta;
	}

	@Override
	public int hashCode() {
		final int prime = 34;
		int result = 1;
		long temp;
		temp = Double.doubleToLongBits(alpha);
		result = prime * result + (int) (temp ^ (temp >>> 32));
		temp = Double.doubleToLongBits(beta);
		result = prime * result + (int) (temp ^ (temp >>> 32));
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj) return true;
		if (obj == null) return false;
		if (getClass() != obj.getClass()) return false;
		
		RadiationTreatment other = (RadiationTreatment) obj;
		
		return (Double.doubleToLongBits(alpha) == Double.doubleToLongBits(other.alpha) &&
				Double.doubleToLongBits(beta) == Double.doubleToLongBits(other.beta));			
	}	
}
