/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.treatments;

import java.util.Iterator;
import java.util.NoSuchElementException;

import de.fhstralsund.catsit.base.treatments.TreatmentList.TreatmentEntry;

/**
 * Iterator for the treatment list.
 * @author Anja Bethge
 *
 */
public class TreatmentIterator implements Iterator<TreatmentEntry> {
	
	//the current treatment entry
	private TreatmentEntry entry;
	
	/**
	 * 
	 * @param firstTreatmentEntry the first entry in the treatment list
	 */
	public TreatmentIterator(TreatmentEntry firstTreatmentEntry) {
		//create a dummy entry as the first entry (it will never be called. only the next entry is called which is the real first entry)
		this.entry = new TreatmentEntry(-1, null, firstTreatmentEntry);
	}

	public boolean hasNext() {
		return !(entry.next == null);
	}

	public TreatmentEntry next() {
		if(!hasNext()){
			throw new NoSuchElementException();
		}else{
			//get the next entry in the list
			entry = entry.next;
		}
		return entry;
	}

	public void remove() {
		throw new UnsupportedOperationException();		
	}

}
