/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.io.excel.merger;

/**
 * represents one sheet of an excel file
 * 
 * @author Sebastian Glöde, Anja Bethge
 */
public class Sheet {
	
	
	private String name;
	private String rId;
	private String sheetId;
	private String fileName;

	/**
	 * gets the filename of the sheet
	 * 
	 * @return filename of the sheet
	 */
	public String getFileName() {
		return fileName;
	}

	/**
	 * gets the name of the sheet
	 * 
	 * @return name of the sheet
	 */
	public String getName() {
		return name;
	}

	/**
	 * sets the name of the sheet
	 * 
	 * @param name name of the sheet
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * gets the reference id of the sheet
	 * 
	 * @return the reference id
	 */
	public String getrId() {
		return rId;
	}

	/**
	 * sets the reference id
	 * 
	 * @param rId the reference id
	 */
	public void setrId(String rId) {
		this.rId = rId;
	}

	/**
	 * returns the sheet id
	 * 
	 * @return the sheet id
	 */
	public String getSheetId() {
		return sheetId;
	}

	/**
	 * sets the sheet id
	 * 
	 * @param sheetId the sheet id
	 */
	public void setSheetId(String sheetId) {
		this.sheetId = sheetId;
	}

	/**
	 * initializies a new sheet
	 * 
	 * @param name the name of the sheet
	 * @param rId the reference id
	 * @param sheetId the id of the sheet
	 */
	public Sheet(String name, String rId, String sheetId) {
		this.name = name;
		this.rId = rId;
		this.sheetId = sheetId;

	}

	/**
	 * sets the sheet id
	 * 
	 * @param fileName the filename
	 */
	public void setFileName(String fileName) {
		this.fileName = fileName;
	}

}
