/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.io.excel.writer;

import de.fhstralsund.catsit.support.LogSampleHistogram;

/**
 * Class to bundle status informations of one single host organ.
 * @author Anja Bethge
 * 
 */
public class ExcelRecordSingleHostOrgan implements ExcelRecord{
	/**
	 * the event time.
	 */
	private long time;
	/**
	 * the time in days.
	 */
	private double timeInDays;

	/**
	 * the number of metastases in the host organ.
	 */
	private long numberMetastases;
	/**
	 * the number of cells in all metastases in the host organ.
	 */
	private long cellsInMetastases;
	/**
	 * the histogram.
	 */
	private LogSampleHistogram histogram;

	/**
	 * @param time the event time (in minutes)
	 * @param timeInDays the time in days
	 * @param numberMetastasis the number of metastases in the host organ
	 * @param cellsInMetastasis the number of cells in all metastases in the host organ
	 * @param histogram the size histogram of all metastases in the host organ
	 */
	public ExcelRecordSingleHostOrgan(long time, double timeInDays,	long numberMetastases, long cellsInMetastases, LogSampleHistogram histogram) {

		if (time < 0 || timeInDays < 0 || numberMetastases < 0 || cellsInMetastases < 0) {
			throw new IllegalArgumentException("At least one argument is negative");
		}

		this.time = time;
		this.timeInDays = timeInDays;
		this.numberMetastases = numberMetastases;
		this.cellsInMetastases = cellsInMetastases;
		this.histogram = histogram;
	}
	
	/**
	 * @return the histogram
	 */
	public LogSampleHistogram getHistogram() {
		return histogram;
	}

	/**
	 * @return the time
	 */
	public long getTime() {
		return time;
	}

	/**
	 * @return the timeInDays
	 */
	public double getTimeInDays() {
		return timeInDays;
	}


	/**
	 * @return the numberMetastasis
	 */
	public long getNumberMetastases() {
		return numberMetastases;
	}

	/**
	 * @return the cellsInMetastasis
	 */
	public long getCellsInMetastases() {
		return cellsInMetastases;
	}

	
	
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result	+ (int) (cellsInMetastases ^ (cellsInMetastases >>> 32));
		result = prime * result	+ ((histogram == null) ? 0 : histogram.hashCode());
		result = prime * result	+ (int) (numberMetastases ^ (numberMetastases >>> 32));
		result = prime * result + (int) (time ^ (time >>> 32));
		long temp;
		temp = Double.doubleToLongBits(timeInDays);
		result = prime * result + (int) (temp ^ (temp >>> 32));
		return result;
	}


	@Override
	public boolean equals(Object obj) {
		if (this == obj) return true;
		if (obj == null) return false;
		if (this.getClass() != obj.getClass()) return false;
		
		ExcelRecordSingleHostOrgan other = (ExcelRecordSingleHostOrgan) obj;
		return (time == other.time && 
				timeInDays == other.timeInDays && 
				numberMetastases == other.numberMetastases &&
				cellsInMetastases == other.cellsInMetastases &&
				((histogram == null)? other.histogram == null : histogram.equals(other.histogram)));		
	}	
}
