/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.io.xml;

import java.util.List;

import de.fhstralsund.catsit.base.Compartment;
import de.fhstralsund.catsit.base.HostOrgan;
import de.fhstralsund.catsit.machine.Technical;

/**
 * This Interface should be used for the MCML Parser.
 *
 * @author Michael Suhr
 *
 * @see MPMLParserImpl
 */
public interface MPMLParser {

    public Compartment getCompartment(String filename) throws ParserException;

    public Technical getTechnical(String filename) throws ParserException;
    
    /**
     * Return a List of the names of all specified host organs. 
     * !!!You have to call the method getCompartment(), before calling this one!!!!
     * @return a list of all specified host organs
     * @throws ParserException when no host organ was found. This will happen if you did not call getCompartment() first.
     */
    public List<HostOrgan> getHostOrgans() throws ParserException;
}
