/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.io.xml;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

import de.fhstralsund.catsit.base.Compartment;
import de.fhstralsund.catsit.base.DiscreteCompartmentType;
import de.fhstralsund.catsit.base.HostOrgan;
import de.fhstralsund.catsit.base.distributions.Distribution;
import de.fhstralsund.catsit.io.xml.ReferenceMap.RefType;
import de.fhstralsund.catsit.support.functions.ColonizationRate;
import de.fhstralsund.catsit.support.functions.Function;

/**
 * Buffers all functions, distributions, host organs, compartment types and compartments
 * @author Michael Suhr
 *
 */
public class ObjectBuffer {

	private final Map<String, Function> functions;
	private final Map<String, Distribution> distributions;
	private final Map<String, HostOrgan> hostOrgans;
	private final Map<String, DiscreteCompartmentType> compartmentTypes;
	private final Map<String, Compartment> compartments;
	private final ReferenceMap unreferenced;
	
	public ObjectBuffer() {
		functions = new HashMap<String, Function>();
		distributions = new HashMap<String, Distribution>();
		hostOrgans = new HashMap<String, HostOrgan>();
		compartmentTypes = new HashMap<String, DiscreteCompartmentType>();
		compartments = new HashMap<String, Compartment>();
		unreferenced = new ReferenceMap();
	}
	
	
	public void putFunction(String key, Function f){
		functions.put(key, f);
	}
	
	public Function getFunction(String key){
		return functions.get(key);
	}
	
	public ColonizationRate getColonisationRate(String key) throws ParserException{
		Function f = functions.get(key);
		
		if(f instanceof ColonizationRate){
			return (ColonizationRate)f;
		
		}else if(f !=null){
			throw new ParserException("The colonization rate is of the wrong type. Its has to be of the Type 'ColonisationRate' but was" + f.getClass().getName());
		}
			
		return null;
	}
	
	public int getFunctionSize(){
		return functions.size();
	}
	
	public void putDistribution(String key, Distribution d){
		distributions.put(key, d);
	}
	
	public Distribution getDistribution(String key){
		return distributions.get(key);
	}
	
	public int getDistributionSize(){
		return distributions.size();
	}
	
	public void putHostOrgan(String key, HostOrgan organ){
		hostOrgans.put(key, organ);
	}
	
	public HostOrgan getHostOrgan(String key){
		return hostOrgans.get(key);
	}
	
	public List<HostOrgan> getHostOrganList(){
		return new ArrayList<HostOrgan>(hostOrgans.values());
	}
	
	public void putCompartmentType(String key, DiscreteCompartmentType ct){
		compartmentTypes.put(key, ct);
	}
	
	public DiscreteCompartmentType getCompartmentType(String key){
		return compartmentTypes.get(key);
	}
	
	public int getCompartmentTypeSize(){
		return compartmentTypes.size();
	}
	
	public void putCompartment(String key, Compartment ct){
		compartments.put(key, ct);
	}
	
	public Compartment getCompartment(String key){
		return compartments.get(key);
	}
	
	public int getCompartmentSize(){
		return compartments.size();
	}
	
	public void putUnreferenced(String ref, RefType type, Object value){
		unreferenced.add(ref, type, value);
	}
	
	public List<Object> getUnreferenced(String key) {
		return unreferenced.get(key);
	}
	
	public int getUnreferencedSize() {
		return unreferenced.size();
	}
	
	public Set<String> getUnreferencedKeySet() {
		return unreferenced.keySet();
	}
	
	public int getUnreferencedKeySize() {
		return unreferenced.keySize();
	}
	
}
