/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.io.xml;

import java.util.ArrayList;
import java.util.List;
import java.util.logging.Logger;

import org.xml.sax.ErrorHandler;
import org.xml.sax.SAXParseException;

/**
 * 
 * @author Michael Suhr
 * 
 */
public class ParserErrorHandler implements ErrorHandler {
	
    private static final Logger logger = Logger.getLogger("metastase.support.xml");
    private List<String> errors = new ArrayList<String>();


    public void error(SAXParseException exception) throws SAXParseException {
        // logger.warning("Error: " + exception.getMessage());
        errors.add(exception.getMessage());
    }


    public void fatalError(SAXParseException exception) throws SAXParseException {
        logger.severe("Fatal error while parsing: " + exception.getMessage());
        throw exception;

    }


    public void warning(SAXParseException exception) {
        // logger.info("Warning: " + exception.getMessage());
        errors.add(exception.getMessage());
    }

    public List<String> getErrors() {
        return this.errors;
    }

    public int errors() {
        return this.errors.size();
    }

}
