/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.io.xml;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * @author Michael Suhr
 * 
 */
public class ReferenceMap {
    private Map<String, List<Object>> references = new HashMap<String, List<Object>>();
    
    public final static String SEPARATOR = ";";
  
    public enum RefType {
        FUNCTION, COMPARTMENT, TYPE
    }

    public Iterator<Object> iterator(String key) {
        return references.get(key).iterator();
    }

    /**
     * Add the specified value with the specified ref to this map. If the map
     * previously contained a mapping for the ref, the new value is added to the
     * list.
     * 
     * @param ref - the missing reference
     * @param type - the type of reference
     * @param value - the value to add.
     */
    public void add(String ref, RefType type, Object value) {
        String key = ref + SEPARATOR + type.toString().toLowerCase();
        if (get(key) == null) {
            references.put(key, new ArrayList<Object>());
        }
        get(key).add(value);
    }
    

    /**
     * Returns the value to which the specified key is mapped, or {@code null}
     * if this map contains no mapping for the key.
     * 
     * @see #put(String, Object)
     */
    public List<Object> get(String key) {
        return references.get(key);
    }

    /**
     * Returns the number of keys in this map.
     *
     * @return the number of lists in this map.
     */
    public int keySize() {
        return references.size();
    }

    /**
     * Returns the number of unreferenced objects in this map.
     * The sum of all elements in Arraylist.
     *
     * @return the number of unreferenced objects.
     */
    public int size() {
        int size = 0;
        Iterator<List<Object>> itVal = references.values().iterator();
        while (itVal.hasNext()) {
            List<java.lang.Object> list = (List<java.lang.Object>) itVal.next();
            size += list.size();
        }
        return size;
    }

    /**
     * Returns the of keys in the map.
     *
     * @return all keys of the map
     */
    public Set<String> keySet() {
        return references.keySet();
    }

}
