/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.io.xml.builder;

import java.util.logging.Logger;

import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import de.fhstralsund.catsit.base.DiscreteCompartmentType;
import de.fhstralsund.catsit.base.DiscreteCompartmentTypeException;
import de.fhstralsund.catsit.io.xml.ObjectBuffer;
import de.fhstralsund.catsit.io.xml.ParserException;

/**
 * This Builder is used to parse a DOM node to a {@link DiscreteCompartmentType}.
 * 
 * @author Michael Suhr, Anja Bethge
 * 
 */
public abstract class CompartmentTypeBuilder {
    protected static final Logger logger = Logger.getLogger("metastase.support.xml.builder");

    public static DiscreteCompartmentType parse(Node node, ObjectBuffer maps) throws ParserException {       
       
        DiscreteCompartmentType type = null;
        
        if (node instanceof Element && "discreteCompartmentType".equals(node.getNodeName())) {
            Element elem = (Element) node;            

            String name = DOMHelper.getElementString(elem, "name");
            logger.fine("name: " + name);
                
            type = new DiscreteCompartmentType(name);
            NodeList events = elem.getElementsByTagName("eventActions").item(0).getChildNodes();
            for (int i = 0; i < events.getLength(); i++) {
                Node event = events.item(i);
                if (event instanceof Element) {
                    type.addPossibleEventAction(EventActionBuilder.parse(event, maps));
                }
            }
            
            try {
				type.checkPossibleEventActions();
			} catch (DiscreteCompartmentTypeException e) {
				throw new ParserException(e);
			}
            	            
            // use the typeID id name as key for the map.
            maps.putCompartmentType(elem.getAttribute("typeID"), type);
        }
        return type;
    }
}
