/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.io.xml.builder;

import java.util.logging.Logger;

import org.w3c.dom.Element;
import org.w3c.dom.Node;

import de.fhstralsund.catsit.base.distributions.Distribution;
import de.fhstralsund.catsit.base.distributions.GaussianDistribution;
import de.fhstralsund.catsit.base.distributions.UniformDistribution;
import de.fhstralsund.catsit.io.xml.ObjectBuffer;

/**
 * This Builder is used to parse a DOM node to a {@link Distribution}.
 * 
 * @author Michael Suhr
 * 
 */
public abstract class DistributionBuilder {
    protected static final Logger logger = Logger.getLogger("metastase.support.xml.builder");

    /**
     * 
     * @param node the DOM node
     * @param maps the object buffer where the distributions will be saved until they are referenced by a host organ
     * @return the distribution object
     */
    public static Distribution parse(Node node, ObjectBuffer maps) {
        String type = node.getNodeName();
        Distribution returnDist = null;
        if (node instanceof Element) {
            Element elem = (Element) node;
            if ("gaussianDistribution".equals(type)) {
                logger.fine("generate gaussian Distribution");
                returnDist = gaussianDistribution(elem);
            } else if ("uniformDistribution".equals(type)) {
                logger.fine("generate uniform Distribution");
                returnDist = uniformDistribution(elem);
            } 
            // use the distribution id as key for the map.
            maps.putDistribution(elem.getAttribute("distID"), returnDist);
        }

        return returnDist;
    }

    private static Distribution gaussianDistribution(Element node) {
        double stdDev = DOMHelper.getElementDouble(node, "stdDev");
        double mean = DOMHelper.getElementDouble(node, "mean");

        return new GaussianDistribution(mean, stdDev);
    }

    private static Distribution uniformDistribution(Element node) {
        double min = DOMHelper.getElementDouble(node, "min");
        double max = DOMHelper.getElementDouble(node, "max");

        return new UniformDistribution(min, max);
    }

}
