/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.io.xml.builder;

import java.util.logging.Logger;

import org.w3c.dom.Element;
import org.w3c.dom.Node;

import de.fhstralsund.catsit.base.HostOrgan;
import de.fhstralsund.catsit.base.distributions.Distribution;
import de.fhstralsund.catsit.io.xml.ObjectBuffer;
import de.fhstralsund.catsit.io.xml.ParserException;

/**
 * This Builder is used to parse a DOM node to a {@link HostOrgan}.
 * 
 * @author Anja Bethge
 *
 */
public abstract class HostOrganBuilder {

    protected static final Logger logger = Logger.getLogger("metastase.support.xml.builder");

    /**
     * 
     * @param node the DOM node
     * @param maps the object buffer where the host organs, distributions and functions are buffered
     */
    public static HostOrgan parse(Node node, ObjectBuffer maps) throws ParserException{
    	
        HostOrgan organ = null;
        
        if (node instanceof Element) {
            Element elem = (Element) node;
            
            String name = DOMHelper.getElementString(elem, "name");
            boolean print = DOMHelper.getElementBoolean(elem,"printHostOrgan", false);
            
            String dormancyRef = DOMHelper.getElementAttribute(elem, "dormancy", "distRef");
            Distribution dormancy = null;
            
            if(dormancyRef != null){
	            dormancy = maps.getDistribution(dormancyRef);
	            if (dormancy == null) {
	            	//Whoops! Where is the associated distribution?
	                throw new ParserException("Could not find the Distribution with id: " + dormancyRef + ". Maybe a misspelling?"); 
	            }
            }
            
            Element lateDormancy = (Element)elem.getElementsByTagName("lateDormancy").item(0);
            
            if(lateDormancy !=null){
            	//check only when a late dormancy is stated in the xml file
            	String lateDormancySizeRef = DOMHelper.getElementAttribute(lateDormancy, "size", "distRef");
                String lateDormancyDurationRef = DOMHelper.getElementAttribute(lateDormancy, "duration", "distRef");
                Distribution lateDormancySize = maps.getDistribution(lateDormancySizeRef);
                Distribution lateDormancyDuration = maps.getDistribution(lateDormancyDurationRef);
                
                if (lateDormancySize == null) {
                	//Whoops! Where is the associated distribution?
                    throw new ParserException("Could not find the Distribution with id: " + lateDormancySizeRef + ". Maybe a misspelling?");
                }
                if (lateDormancyDuration == null) {
                	//Whoops! Where is the associated distribution?
                    throw new ParserException("Could not find the Distribution with id: " + lateDormancyDurationRef + ". Maybe a misspelling?");
                }
                
				organ = new HostOrgan(name, dormancy, lateDormancySize, lateDormancyDuration, print);				
            
            }else{
            	organ = new HostOrgan(name, dormancy, print);
            }            
            
            // use the organ id as key for the map.
            maps.putHostOrgan(elem.getAttribute("organID"), organ);
        }

        return organ;
    }
}
