/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.machine;

import de.fhstralsund.catsit.support.functions.Function;
import de.fhstralsund.catsit.support.randoms.RandomG;

/**
 * abstract super class for event time calculator, e.g. {@link AdaptiveIntegrationCalculator}} 
 * 
 * @author Gero Wedemann
 * @author Anja Bethge
 */
public abstract class EventTimeCalculator {
	
	private RandomG rng;
	
	private Function eventRateFunction;

	
	/**
	 * 
	 * @param eventRateFunction the rate at which the events are created
	 */
	public EventTimeCalculator(Function eventRateFunction) {
		
		this.rng = RandomG.getInstance();
		this.eventRateFunction = eventRateFunction;
	}
	
	protected RandomG getRng() {
		return rng;
	}
	
	/**
	 * Sets the RandomG instance. Only used for testing the AdaptiveIntegrativeEventGenerator.
	 * @param random the RandomG instance to set
	 */
	public void setRandomG(RandomG random){
		this.rng = random;
	}

	public Function getEventRateFunction(){
		return eventRateFunction;
	}
	
	public abstract double computeTimeToNextEvent(double currentTime) throws TumorIsDeadException;
	
}
