/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.machine;


/**
 * 
 * This class contains all technical information of the simulation.
 * 
 * @author Michael Suhr
 *
 */
public class Technical {
	private long duration;
    private double timeStepsForSaving;
    
    private boolean debugMode;
    
    /**
     * 
     * @param timeStepsForSaving the interval the system status shall be printed (Unit: days) 
     * @param duration the duration the system shall be simulated (Unit: days)
     * @param debugMode true, if further informations shall be printed during the simulation or false, otherwise
     */
    public Technical(long duration, double timeStepsForSaving, boolean debugMode) {
    	this.duration = duration*60*24;
        this.timeStepsForSaving = timeStepsForSaving*60*24;
        this.debugMode = debugMode;
    }

    /**
     * @return the duration in <b>days</b>
     */
    public long getDuration() {
        return this.duration/60/24;
    }
    
    /**
     * @return the duration in <b>minutes</b>
     */
    public long getDurationInMinutes() {
        return this.duration;
    }
    
    /**
     * @return the timeStepsForSaving in <b>days</b>
     */
    public double getTimeStepsForSaving() {
        return this.timeStepsForSaving/60/24;
    }
    
    /**
     * @return the timeStepsForSaving in <b>minutes</b>
     */
    public double getTimeStepsForSavingInMinutes() {
        return this.timeStepsForSaving;
    }

	/**
     * @return true if the debugMode is set, otherwise false
     */
    public boolean isDebugMode() {
        return this.debugMode;
    }

    @Override
    public String toString() {
        return "Technical:timeStepsForSaving=" + getTimeStepsForSaving() + ", duration=" + getDuration() + ", " +
        "debug-mode="+ isDebugMode();
    }

}
