/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.machine.eventlists;

import java.util.Iterator;
import java.util.NoSuchElementException;

import de.fhstralsund.catsit.base.Event;
import de.fhstralsund.catsit.machine.eventlists.HenriksenEventList.Entry;

/**
 * Iterator for the Hendriksen event list
 * @author Anja Bethge
 *
 */
public class HenriksenIterator implements Iterator<Event> {

	private Entry entry;
	
	public HenriksenIterator(HenriksenEventList henriksenList) {
		//the first entry is only a dummy entry, to mark the start of the linked list
		this.entry = henriksenList.getFirstEntry();
	}

	
	public boolean hasNext() {
		return (entry.right != null && entry.right.time != HenriksenEventList.MAX_VALUE);
	}


	public Event next() {
		if(!hasNext()){
			throw new NoSuchElementException();
		}else{
			//get the next entry in the list
			entry = entry.right;
		}
		return entry.event;
	}


	public void remove() {
		throw new UnsupportedOperationException();
	}

}
