/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.machine.eventlists;

import java.util.ArrayList;
import java.util.Iterator;

import de.fhstralsund.catsit.base.Event;
import de.fhstralsund.catsit.machine.EventList;
import de.fhstralsund.catsit.machine.NoEventLeftException;

/** 
 * the most simplest implementation of an eventlist
 * 
 * @author Gero Wedemann
 */
public class SimpleEventList extends EventList{
	
	private ArrayList<Event> eventlist;
	// the time until which events shall be added to the list. Events with a time greater than 
	// the deadline are ignored and not sorted into the list.
	private double deadLine; 
	
	public SimpleEventList() {
		super();
		eventlist = new ArrayList<Event>();
	}
	
	public void addEvent(Event event) {
		
		//return, if the time of the event lies after the deadline
		//since we will never process this event, we don't have to sort it into the list
		if(event.getTime() > deadLine) return;		
		
		boolean added = false;
		
		//the events in the list are ordered by the time
		//sort the event into the list (regarding the time)
		for(int i=0; i<eventlist.size(); i++) {
			Event listedEvent = eventlist.get(i);
			if (event.getTime() <= listedEvent.getTime()) {
				eventlist.add(i,event);
				added = true;
				break;
			}
		}
		
		if (!added) {
			eventlist.add(event);
		}
		
	}


	public boolean isEmpty() {
		return eventlist.isEmpty();
	}


	public Event nextEvent() throws NoEventLeftException {
		try {
			return eventlist.remove(0);
		}
		catch(IndexOutOfBoundsException e) {
			throw new NoEventLeftException();
		}
	}


	public Iterator<Event> iterator() {
		return eventlist.iterator();
	}


	public Event removeEvent(Event e) {
		return eventlist.remove(eventlist.indexOf(e));
	}

	@Override
	public void setDeadline(double deadLine) {
		this.deadLine = deadLine;		
	}

}
