/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support;

public class HistogramEntry extends SampleStatistic{
	
	private double lowerLimit;
	private double upperLimit;
	
	
	public HistogramEntry(double lowerLimit, double upperLimit) {
		super();
		if(upperLimit<=lowerLimit){
			throw new IllegalArgumentException("The upper limit ("+upperLimit+") must not be smaller or equal than the lower limit ("+lowerLimit+")!");
		}
		
		this.lowerLimit = lowerLimit;
		this.upperLimit = upperLimit;
	}
	
	@Override
	public void add(double val) {
		if(val<lowerLimit){
			throw new IllegalArgumentException("The value ("+val+") must not be smaller than the lower limit ("+lowerLimit+")!");
		}
		if(val>=upperLimit){
			throw new IllegalArgumentException("The value ("+val+") must not be bigger or euqal than the upper limit ("+lowerLimit+")!");
		}
				
		super.add(val);
	}
	
	public boolean isInLimits(double val) {
		if (val>=lowerLimit && val<upperLimit) {
			return true;
		}
		return false;
	}

	public double getLowerLimit() {
		return lowerLimit;
	}

	public double getUpperLimit() {
		return upperLimit;
	}

	
	

	@Override
	public String toString() {
		return "HistogramEntry ["+super.toString()+" lowerLimit=" + lowerLimit + ", upperLimit="	+ upperLimit + "]";
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = super.hashCode();
		long temp;
		temp = Double.doubleToLongBits(lowerLimit);
		result = prime * result + (int) (temp ^ (temp >>> 32));
		temp = Double.doubleToLongBits(upperLimit);
		result = prime * result + (int) (temp ^ (temp >>> 32));
		return result;
	}


	@Override
	public boolean equals(Object obj) {
		if (this == obj) return true;
		if (!super.equals(obj)) return false;
		
		HistogramEntry other = (HistogramEntry) obj;
		return (lowerLimit == other.lowerLimit && upperLimit == other.upperLimit);
	}
}
