/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support;

/**
 * Provides special math functions. 
 * 
 * @author AnjaBethge
 *
 */
public class SpecialMath {
	
	/**
	 * This method is necessary due to occasional rounding errors that can occur when 
	 * computing with double values.<br>
	 * In this simulation there are no partial cells such as 0.76 or 2.65. A cell is either 
	 * complete or not existing. Hence a value of 2.65 cells is rounded to 2 cells while a 
	 * value of 0.76 is rounded to 0 cells.<br>
	 * Unfortunately, when computing with double values, rounding errors might lead to a value 
	 * of e.g. 3.999845... instead of the correct value 4. Hence, we use an adapted version 
	 * of the round method were 0.01 is added to the given value (instead of 0.5) before it 
	 * is casted to long.<br>
	 * So, e.g. 1.998 is rounded up to 2, while 1.989 is rounded down to 1.
	 * @param value the value to round
	 * @return the rounded long value
	 */
	public static long round(double value) {
		return (long)(value + 0.01);
	}
	
}