/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support.functions;

/**
 * Returns the value, specified in the constructor or 1, if no return value was specified.
 * @author Anja Bethge
 * @author Michael Suhr
 */
public class ConstantFunction implements Function {
	
	private double returnValue;
	
	public ConstantFunction() {
		returnValue = 1;
	}
	
	public ConstantFunction(double returnValue) {
		this.returnValue = returnValue;
	}
	
	
	public double getReturnValue(){
		return returnValue;
	}
	
	/**
	 *  Returns the value, specified in the constructor or 1, if no return value was specified.
	 */
	public double f(double x) {
		return returnValue;
	}
	

	public double f_FirstDerivation(double x) {
		// the value of the first derivation is always 0
		return 0;
	}

	
	//////////// toString(), equals() & hashCode() ////////////////////////////////////////////////////////////////////////////////////////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////   
	@Override
	public String toString() {
		return "ConstantFunction [returnValue=" + returnValue + "]";
	}

	public boolean equals(Object obj) {
        if (obj == null) return false;
        if (this == obj) return true;
        if(this.getClass() != obj.getClass()) return false;
        
        return (this.returnValue == ((ConstantFunction) obj).returnValue);
	}

    @Override
    public int hashCode() {
        int result = 17;
        long temp = Double.doubleToLongBits(returnValue);
        result = 37 * result + (int)(temp ^ (temp >>> 32));
        return result;
    }
    ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////   

}
