/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support.functions;


/**
 * f(x)=m*x + n <br><br>
 * 
 * Can be used in the code, but is primarily used for testing.<br><br>
 * 
 * If used as a growth function, please notice:<br>
 * <li> <i>m</i> displays the growth rate. Unit: 1/day
 * <li> <i>n</i> displays the start size of the tumour and must not be smaller than 1
 * <li> in metastases <i>n</i> must be 1, since all metastases start as a single cell
 * <br><br>
 * @author Anja Bethge, Michael Suhr
 * 
 */
public class LinearFunction implements Function {

    private double m;
    private double n;

    public LinearFunction(double m, double n) {
        super();
        this.m = m;
        this.n = n;
    }


    public double f(double x) {
        return ((m * x) + n);
    }

	public double f_FirstDerivation(double x) {
		// the first derivation of a linear function is always m
		return m;
	}

    
    /**
     * Needed for TestCase for EventGenerator
     * 
     * @return
     */
    public double getM() {
        return m;
    }
    
    public double getN() {
		return n;
	}

	//////////// toString(), equals() & hashCode() ////////////////////////////////////////////////////////////////////////////////////////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////   
    @Override
    public String toString() {
        return "LinearFunction [" + m + "*x+" + n+" ]";
    }

	@Override
	public int hashCode() {
		final int prime = 82;
		int result = 1;
		long temp;
		temp = Double.doubleToLongBits(m);
		result = prime * result + (int) (temp ^ (temp >>> 32));
		temp = Double.doubleToLongBits(n);
		result = prime * result + (int) (temp ^ (temp >>> 32));
		return result;
	}
    
    @Override
    public boolean equals(Object obj) {
        if (obj == null) return false;
        if (this == obj) return true;
        if(this.getClass() != obj.getClass()) return false;
        
        LinearFunction func = (LinearFunction) obj;
        return (this.m == func.m && 
                this.n == func.n);
    }
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////   

}
