/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support.functions.chemo.derivations;

/**
 * The first derivation of the gompertz chemotherapy function.
 * @author Anja Bethge
 *
 */
public class GompertzChemoFunctionFirstDerivation extends	BasicChemoFunctionDerivation {

	private double a;
	private double b;
	
	
	public GompertzChemoFunctionFirstDerivation(double a, double b, double cyclingCellsFraction, double drugDecayRate, double drugSensitivity, 
			long chemoStartSize, double delay) {
		super(cyclingCellsFraction, drugDecayRate, drugSensitivity, chemoStartSize, delay);
		this.a = a;
		this.b = b;
	}


	public double f(double x) {
		double t = x;
		double c = getCyclingCellsFraction();
		double s = getDrugSensitivity();
		double d = getDrugDecayRate();
		double n = getChemoStartSize();
		double l = getDelay();
		
		double o = a-d;
		double p = b/n;
		double q = l*d;
		
		double part1 = -1.*a*t - q - (c*s*Math.exp(-1.*a*t - q)*(Math.exp(t*o) - 1))/o;
		double part2 = c*s*(-1.*a + d*Math.exp(t*o)) + a*o*Math.exp(q)*Math.log(p);
		
		return b/o * Math.exp(part1) * Math.pow(p, -1.*Math.exp(-1.*a*t)) * part2; 
	}

}
