/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support.functions.chemo.derivations;

/**
 * The second derivation of the gompertz chemotherapy function.
 * @author Anja Bethge
 *
 */
public class GompertzChemoFunctionSecondDerivation extends	BasicChemoFunctionDerivation {

	private double a;
	private double b;
	
	
	public GompertzChemoFunctionSecondDerivation(double a, double b, double cyclingCellsFraction, double drugDecayRate, double drugSensitivity, 
			long chemoStartSize, double delay) {
		super(cyclingCellsFraction, drugDecayRate, drugSensitivity, chemoStartSize, delay);
		this.a = a;
		this.b = b;
	}


	public double f(double x) {
		double t = x;
		double c = getCyclingCellsFraction();
		double s = getDrugSensitivity();
		double d = getDrugDecayRate();
		double n = getChemoStartSize();
		double l = getDelay();
		
		double o = a-d;
		double p = b/n;
		double q = d*(t+l);
		double r = c*s;
		
		double part1 = (a*a*a) * Math.exp(a*t+2.*t*d+l*d) + (d*d)*(r+d*Math.exp(q))*Math.exp(2.*a*t) - (a*a)*(-1.*r+d*Math.exp(a*t+l*d))*Math.exp(2.*d*t) 
				- a*d*(2.*r+d*Math.exp(a*t+l*d))*Math.exp(t*(a+d));
		
		double part2 = (a*a)*Math.exp(a*t+2.*q) - 2.*r*d*Math.exp(a*t+q) - a*(-2.*r+d*Math.exp(a*t+l*d))*Math.exp(d*(2.*t+l));		
		double part3 = Math.exp(-2.*a*t - 2.*t*d - 2.*l*d - (r*(Math.exp(t*o)-1)*Math.exp(-1.*a*t-l*d))/o);
		double part4 = (a*a)*(o*o)*(Math.log(p)*Math.log(p))*Math.exp(2.*q);
		
		return 1/(o*o) * b * part3 * Math.pow(p, -1.*Math.exp(-1.*a*t)) * (r * part1 - a*o*part2*Math.log(p) + part4);
	}

}
