/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support.functions.chemo.derivations;

import numal.Special_functions;

/**
 * The first derivation of the linear chemotherapy function.
 * @author Anja Bethge
 *
 */
public class LinearChemoFunctionFirstDerivation extends	BasicChemoFunctionDerivation {

	private double m;
	
	
	public LinearChemoFunctionFirstDerivation(double m, double cyclingCellsFraction, double drugDecayRate, double drugSensitivity, 
			long chemoStartSize, double delay) {
		super(cyclingCellsFraction, drugDecayRate, drugSensitivity, chemoStartSize, delay);
		this.m = m;
	}

	public double f(double x) {
		double t = x;
		double c = getCyclingCellsFraction();
		double s = getDrugSensitivity();
		double d = getDrugDecayRate();
		double n = getChemoStartSize();
		double l = getDelay();
		
		double z = (c*s*Math.exp(-1.*d*l))/d;
		double p = (c*s*Math.exp(-1.*d*(t+l)))/d;
		
		return Math.exp(z*(Math.exp(-1.*t*d)-1))*(m*Math.exp(p*(Math.exp(t*d)-1)) - p*(d*n + m*Math.exp(z)*(Special_functions.ei(-1.*z)-Special_functions.ei(-1.*p))));
	}

}
