/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support.randoms;

import java.util.Date;
import java.util.logging.Level;
import java.util.logging.Logger;


/**
 * simple implementation of a random number generator
 * 
 * @author Gero Wedemann
 */
public class Random16807 extends RandomG{
	private static final Logger logger = Logger.getLogger("metastase.support");
	private static final long LONG_MAX = 2147483647L;
	private static final long QUOTIENT  = LONG_MAX / 16807L;
	private static final long REMAINDER_LI = LONG_MAX % 16807L;
	
	private long val;
	
	public Random16807() {
		long initSeed = new Date().getTime();
		try {
			setSeed(initSeed);
		} catch (RandomGException e) {
			logger.log(Level.SEVERE, "unexpected exception: " + e);
			throw new RuntimeException(e);
		}
		
	    for (int i = 0; i <1000 ; i++)  // warm up of RNG
	        getLong();
	}
	
	public Random16807(long initSeed) throws RandomGException {
	    setSeed(initSeed);
	}

	void setSeed(long seed) throws RandomGException {	
	    if ( seed<=0 ) {
	        throw new RandomGException("seed must be >0");
	    }
	    
	    seed = seed%LONG_MAX;
	    val=seed|1;   // make seed odd
	}

	/**
	 * @return random long between 0 and LONG_MAX
	 */
	public synchronized long getLong() {
	    if ( val <= QUOTIENT )
	        val = (val * 16807L) % LONG_MAX;
	    else {
	        long highPart = val / QUOTIENT;
	        long lowPart  = val % QUOTIENT;

	        long test = 16807L * lowPart - REMAINDER_LI * highPart;

	        if ( test > 0 )
	            val = test;
	        else
	            val = test + LONG_MAX;
	    }
	    return val;
	}

	@Override
	public double getDouble() {
	    long new_rand = getLong();
	    return new_rand / (double)( LONG_MAX );
	}

}
