/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support.randoms;


/**
 * The authors of this work have released all rights to it and placed it in the
 * public domain under the Creative Commons CC0 1.0 waiver
 * (http://creativecommons.org/publicdomain/zero/1.0/).
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 * 
 * Retrieved from:
 * http://en.literateprograms.org/Mersenne_twister_(Java)?oldid=5676
 * 06.11.2014
 * 
 * ------------------------------------------------------------------------------
 * ------------------------------------------------------------------------------
 * 
 * The Mersenne Twister is a new random number generator, 
 * invented/discovered in 1996 by Matsumora and Nishimura.
 * 
 * MT is a twisted GFSR(624,397), similar in spirit to R250
 * and in my tests it's comparable in speed to R250 (slightly 
 * slower than R250 alone, but faster than R250/521 combined).
 * It takes up more space than R250 or R521, but less than the
 * two combined. MT has an amazing period of 2^19937-1. Overall,
 * I'd have to say that the Mersenne Twister is my current 
 * favorite random number generator.
 * 
 * 
 * Original retrieved from:
 * http://www.qbrundage.com/michaelb/pubs/essays/random_number_generation.html
 * 25.06.2008 (not available there any more and no license information)
 * 
 * ------------------------------------------------------------------------------
 * ------------------------------------------------------------------------------
 * 
 * adapted by Gero Wedemann
 * 
 * @author Michael Brundage
 * @author Gero Wedemann
 */

public final class RandomMT extends RandomG {
    private int mt_index;
    private int[] mt_buffer = new int[624];

    public RandomMT() {
        java.util.Random r = new java.util.Random();
        for (int i = 0; i < 624; i++)
            mt_buffer[i] = r.nextInt();
        mt_index = 0;
    }

    public int random() {
        if (mt_index == 624)
        {
            mt_index = 0;
            int i = 0;
            int s;
            for (; i < 624 - 397; i++) {
                s = (mt_buffer[i] & 0x80000000) | (mt_buffer[i+1] & 0x7FFFFFFF);
                mt_buffer[i] = mt_buffer[i + 397] ^ (s >> 1) ^ ((s & 1) * 0x9908B0DF);
            }
            for (; i < 623; i++) {
                s = (mt_buffer[i] & 0x80000000) | (mt_buffer[i+1] & 0x7FFFFFFF);
                mt_buffer[i] = mt_buffer[i - (624 - 397)] ^ (s >> 1) ^ ((s & 1) * 0x9908B0DF);
            }
        
            s = (mt_buffer[623] & 0x80000000) | (mt_buffer[0] & 0x7FFFFFFF);
            mt_buffer[623] = mt_buffer[396] ^ (s >> 1) ^ ((s & 1) * 0x9908B0DF);
        }
        return mt_buffer[mt_index++];
    }
    
	@Override
	public double getDouble() {
	    int new_rand = random();
	    double new_rand_d = new_rand / (double)( Integer.MAX_VALUE ); // -1 .. +1
	    new_rand_d = (new_rand_d + 1.)/2.; // 0 ..1
	    return new_rand_d;
	}
    
    @Override
    public boolean equals(Object obj) {
        if (obj == null) 
            return false;
        if (this == obj)
            return true;
        if(this.getClass() != obj.getClass())
            return false;

        RandomMT rand = (RandomMT) obj;
        return (this.mt_index == rand.mt_index && 
                this.mt_buffer.length == rand.mt_buffer.length);
    }
}
