/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.mockobjects.MockCompartment;
import de.fhstralsund.catsit.base.mockobjects.MockHostOrgan;

/**
 * Test cases for {@link metastase.base.CompartmentInventory}
 * 
 * @author Gero Wedemann
 */
public class TestCompartmentInventory extends TestCase {
	@Override
	public void setUp() {
		CompartmentInventory.reset();
		CompartmentInventory.resetCompartmentCounter();
	}
	
	public void testNormal() {
		
		DiscreteCompartmentType aCompartmentType = new DiscreteCompartmentType("example");
		DiscreteCompartment newCompartment = new DiscreteCompartment(0, new MockHostOrgan(), aCompartmentType, false);
		assertEquals( newCompartment, CompartmentInventory.getCompartments().get(0) );
		assertEquals( 1, CompartmentInventory.getCompartments().size() );
			
		newCompartment = new DiscreteCompartment(0, new MockHostOrgan(), aCompartmentType, false);
		assertTrue( CompartmentInventory.getCompartments().get(0) != null );
		assertEquals( newCompartment, CompartmentInventory.getCompartments().get(1) );
		assertEquals( 2, CompartmentInventory.getCompartments().size() );
		
	}
	
	public void testCreateID(){
		try{
			Compartment compartment = new MockCompartment();
			Compartment compartment2 = new MockCompartment();
			
			assertTrue(compartment.sameAs(compartment));
			assertFalse(compartment.sameAs(compartment2));
			
			//reset the compartment counter to check whether createID yields unique IDs
			CompartmentInventory.resetCompartmentCounter();
			assertFalse(compartment.sameAs(new MockCompartment()));
			
			
		} catch (MetastaseException e) {
			e.printStackTrace();
			fail("unexpected exeption");
		}
	}
	
	public void testEmpty(){
		assertEquals( 0, CompartmentInventory.getCompartments().size() );
		new CompartmentInventory();//to cover the header
	}
}
