/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.GlobalEvent;
import de.fhstralsund.catsit.base.eventactions.globaleventactions.GlobalEventAction;
import de.fhstralsund.catsit.base.mockobjects.MockGlobalEventAction;

public class TestGlobalEvent extends TestCase {

	
	public void testIt() throws Exception{
		
		
		GlobalEventAction gea = new MockGlobalEventAction("name");
		GlobalEventAction gea2 = new MockGlobalEventAction("name2");
		GlobalEvent ge = new GlobalEvent(gea, 0.);
		
		//getEventAction
		assertEquals(gea, ge.getEventAction());
		ge.execute();
		
		//toString
		assertEquals("GlobalEvent [time=0.0, eventAction=GlobalEventAction [name=name]]", ge.toString());
		
		//equals and hashCode
		assertTrue(ge.equals(ge));
		assertTrue(ge.hashCode() == ge.hashCode());
		assertTrue(ge.equals(new GlobalEvent(gea, 0.)));
		assertTrue(ge.hashCode() == new GlobalEvent(gea, 0.).hashCode());
		
		assertFalse(ge.equals(null));
		assertFalse(ge.equals(new GlobalEvent(gea, 1.)));
		assertFalse(ge.hashCode() == new GlobalEvent(gea, 1.).hashCode());
		
		assertFalse(ge.equals(new GlobalEvent(gea2, 0.)));
		assertFalse(ge.hashCode() == new GlobalEvent(gea2, 0.).hashCode());
		
		ge = new GlobalEvent(null, 0.);
		assertFalse(ge.equals(new GlobalEvent(gea, 0.)));
		assertFalse(ge.hashCode() == new GlobalEvent(gea, 0.).hashCode());
		assertTrue(ge.equals(new GlobalEvent(null, 0.)));
		assertTrue(ge.hashCode() == new GlobalEvent(null, 0.).hashCode());
	}
	
}
