/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.HostOrgan;
import de.fhstralsund.catsit.base.mockobjects.MockDistribution;
import de.fhstralsund.catsit.support.functions.ConstantFunction;

public class TestHostOrgan extends TestCase {

	
	public void testConstructor(){
		
		try {
			new HostOrgan("a", null, null, new MockDistribution(), false);
			fail("An exception should have been thrown");
		} catch (IllegalArgumentException e) {
			// we are supposed to be here
		}
		
		try {
			new HostOrgan("a", null, new MockDistribution(), null, false);
			fail("An exception should have been thrown");
		} catch (IllegalArgumentException e) {
			// we are supposed to be here
		}
		
		try {
			new HostOrgan("a", null, null, null, false);
			// we are supposed to be here
		} catch (IllegalArgumentException e) {			
			fail("Whoops!" + e.getMessage());
		}
		
		try {
			new HostOrgan("a", null, new MockDistribution(), new MockDistribution(), false);
			// we are supposed to be here
		} catch (IllegalArgumentException e) {			
			fail("Whoops!" + e.getMessage());
		}
	}
	
	public void testGettersAndStuff() throws Exception{
		HostOrgan ho = new HostOrgan("organ", true);
		
		assertEquals("organ", ho.getName());
		assertFalse(ho.hasDormancy());
		assertFalse(ho.hasLateDormancy());
		assertTrue(ho.isPrintFileForHostOrgan());		
		
		ho = new HostOrgan("organ", new MockDistribution(), false);
		
		assertTrue(ho.hasDormancy());
		assertFalse(ho.hasLateDormancy());		
		assertFalse(ho.isPrintFileForHostOrgan());
		
		ho = new HostOrgan("organ", null, new MockDistribution(), new MockDistribution(), false);
		assertFalse(ho.hasDormancy());
		assertTrue(ho.hasLateDormancy());
		
		assertEquals("HostOrgan [name=organ, dormancy=null, lateDormancySize=MockDistribution [returnValue=1.0], "
				+ "lateDormancyDuration=MockDistribution [returnValue=1.0], printFileForHostOrgan=false]", 
				ho.toString());
	}
	
	public void testDormancy() throws Exception{
		HostOrgan ho = new HostOrgan("organ", new MockDistribution(), new MockDistribution(), new MockDistribution(), false);
		
		assertEquals(1.0, ho.computeDormancyTime());
		assertEquals(1, ho.computeLateDormancySize());
		assertEquals(1.0, ho.computeLateDormancyDuration());
		
		ho = new HostOrgan("organ", null, false);
		try {
			ho.computeDormancyTime();
			fail("An exception should have been thrown");			
		} catch (NullPointerException e) {			
			// we are supposed to be here
		}
		
		try {
			ho.computeLateDormancySize();
			fail("An exception should have been thrown");			
		} catch (NullPointerException e) {			
			// we are supposed to be here
		}
		
		try {
			ho.computeLateDormancyDuration();
			fail("An exception should have been thrown");			
		} catch (NullPointerException e) {			
			// we are supposed to be here
		}
	}
	
	
	public void testEqualsAndHashCode() throws Exception{
		HostOrgan ho = new HostOrgan("organ", new MockDistribution(), false);
		
		assertTrue(ho.equals(ho));
		assertTrue(ho.hashCode() == ho.hashCode());
		assertTrue(ho.equals(new HostOrgan("organ", new MockDistribution(), false)));
		assertTrue(ho.hashCode() == new HostOrgan("organ", new MockDistribution(), false).hashCode());
		
		assertFalse(ho.equals(null));
		assertFalse(ho.equals(new ConstantFunction()));
		assertFalse(ho.hashCode() == new ConstantFunction().hashCode());
		
		//name
		assertFalse(ho.equals(new HostOrgan("organ2", new MockDistribution(), false)));
		assertFalse(ho.hashCode() == new HostOrgan("organ2", new MockDistribution(), false).hashCode());
		//dormancy
		assertFalse(ho.equals(new HostOrgan("organ", new MockDistribution(2), false)));
		assertFalse(ho.hashCode() == new HostOrgan("organ", new MockDistribution(2), false).hashCode());		
		//print
		assertFalse(ho.equals(new HostOrgan("organ", new MockDistribution(), true)));
		assertFalse(ho.hashCode() == new HostOrgan("organ", new MockDistribution(), true).hashCode());
		
		//late dormancy size
		assertFalse(ho.equals(new HostOrgan("organ", new MockDistribution(), new MockDistribution(), new MockDistribution(),  false)));
		assertFalse(ho.hashCode() == new HostOrgan("organ", new MockDistribution(), new MockDistribution(), new MockDistribution(), false).hashCode());
		//late dormancy durartion
		assertFalse(ho.equals(new HostOrgan("organ", new MockDistribution(), new MockDistribution(), new MockDistribution(), false)));
		assertFalse(ho.hashCode() == new HostOrgan("organ", new MockDistribution(), new MockDistribution(), new MockDistribution(), false).hashCode());
		
		//name
		ho = new HostOrgan(null, new MockDistribution(), new MockDistribution(), new MockDistribution(), false);
		assertFalse(ho.equals(new HostOrgan("organ", new MockDistribution(), new MockDistribution(), new MockDistribution(), false)));
		assertFalse(ho.hashCode() == new HostOrgan("organ", new MockDistribution(), new MockDistribution(), new MockDistribution(), false).hashCode());
		assertTrue(ho.equals(new HostOrgan(null, new MockDistribution(), new MockDistribution(), new MockDistribution(), false)));
		assertTrue(ho.hashCode() == new HostOrgan(null, new MockDistribution(), new MockDistribution(), new MockDistribution(), false).hashCode());
		
		//dormancy
		ho = new HostOrgan("organ", null, new MockDistribution(), new MockDistribution(), false);
		assertFalse(ho.equals(new HostOrgan("organ", new MockDistribution(), new MockDistribution(), new MockDistribution(), false)));
		assertFalse(ho.hashCode() == new HostOrgan("organ", new MockDistribution(), new MockDistribution(), new MockDistribution(), false).hashCode());
		assertTrue(ho.equals(new HostOrgan("organ", null, new MockDistribution(), new MockDistribution(), false)));
		assertTrue(ho.hashCode() == new HostOrgan("organ", null, new MockDistribution(), new MockDistribution(), false).hashCode());
		
		//late dormancy
		ho = new HostOrgan("organ", null, new MockDistribution(), new MockDistribution(), false);
		assertFalse(ho.equals(new HostOrgan("organ", null, new MockDistribution(5), new MockDistribution(), false)));
		assertFalse(ho.hashCode() == new HostOrgan("organ", null, new MockDistribution(5), new MockDistribution(), false).hashCode());
		assertTrue(ho.equals(new HostOrgan("organ", null, new MockDistribution(), new MockDistribution(), false)));
		assertTrue(ho.hashCode() == new HostOrgan("organ", null, new MockDistribution(), new MockDistribution(), false).hashCode());
		
		assertFalse(ho.equals(new HostOrgan("organ", null, new MockDistribution(), new MockDistribution(5), false)));
		assertFalse(ho.hashCode() == new HostOrgan("organ", null, new MockDistribution(), new MockDistribution(5), false).hashCode());
		
	}
}
