/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.Compartment;
import de.fhstralsund.catsit.base.CompartmentInventory;
import de.fhstralsund.catsit.base.LocalEvent;
import de.fhstralsund.catsit.base.eventactions.localeventactions.LocalEventAction;
import de.fhstralsund.catsit.base.mockobjects.MockCompartment;
import de.fhstralsund.catsit.base.mockobjects.MockLocalEventAction;

public class TestLocalEvent extends TestCase {

	
	public void testIt() throws Exception{
		
		CompartmentInventory.reset();
		CompartmentInventory.resetCompartmentCounter();
		LocalEventAction lea = new MockLocalEventAction("name");
		LocalEventAction lea2 = new MockLocalEventAction("name2");
		Compartment c = new MockCompartment();
		LocalEvent le = new LocalEvent(lea, 0., c);
		
		//getEventAction, getCompartment
		assertEquals(lea, le.getEventAction());
		assertEquals(c, le.getCompartment());
		le.execute();
		
		//toString
		assertEquals("LocalEvent [time=0.0, eventAction=MockLocalEventAction [name=name], compartment=myId=1, name=mock compartment, "
				+ "isPrimaryTumor=false, isBloodStream=false, hostOrgan=HostOrgan [name=mock organ, dormancy=null, lateDormancySize=null, "
				+ "lateDormancyDuration=null, printFileForHostOrgan=false], successor=null, isDormant=false, isInLateDormancy=false, "
				+ "lateDormancyStartSize=0, lateDormancyDuration=0.0]", 
				le.toString());
		
		//equals and hashCode
		assertTrue(le.equals(le));
		assertTrue(le.hashCode() == le.hashCode());
		assertTrue(le.equals(new LocalEvent(lea, 0., c)));
		assertTrue(le.hashCode() == new LocalEvent(lea, 0., c).hashCode());
		
		assertFalse(le.equals(null));
		assertFalse(le.equals(new LocalEvent(lea, 1., c)));
		assertFalse(le.hashCode() == new LocalEvent(lea, 1., c).hashCode());
		
		assertFalse(le.equals(new LocalEvent(lea, 0., new MockCompartment("bla"))));
		assertFalse(le.hashCode() == new LocalEvent(lea, 0., new MockCompartment("bla")).hashCode());
		
		assertFalse(le.equals(new LocalEvent(lea2, 0., c)));
		assertFalse(le.hashCode() == new LocalEvent(lea2, 0., c).hashCode());
		
		le = new LocalEvent(null, 0., c);
		assertFalse(le.equals(new LocalEvent(lea, 0., c)));
		assertFalse(le.hashCode() == new LocalEvent(lea, 0., c).hashCode());
		assertTrue(le.equals(new LocalEvent(null, 0., c)));
		assertTrue(le.hashCode() == new LocalEvent(null, 0., c).hashCode());
		
		le = new LocalEvent(lea, 0., null);
		assertFalse(le.equals(new LocalEvent(lea, 0., c)));
		assertFalse(le.hashCode() == new LocalEvent(lea, 0., c).hashCode());
		assertTrue(le.equals(new LocalEvent(lea, 0., null)));
		assertTrue(le.hashCode() == new LocalEvent(lea, 0., null).hashCode());		
	}
	
}
