/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.DiscreteCompartmentType;
import de.fhstralsund.catsit.base.ScheduledCompartmentType;
import de.fhstralsund.catsit.base.mockobjects.MockCondition;
import de.fhstralsund.catsit.support.functions.ConstantFunction;

public class TestScheduledCompartmentType extends TestCase {
	
	private ScheduledCompartmentType sct1;
	private ScheduledCompartmentType sct2;
	
	@Override
	protected void setUp() throws Exception {
		sct1 = new ScheduledCompartmentType(new MockCondition(true), new DiscreteCompartmentType("123"));
		sct2 = new ScheduledCompartmentType(new MockCondition(true), new DiscreteCompartmentType("123"));
	}
	
	public void testEqualsAndHashCode() throws Exception{	
		assertNotNull(sct1.getCompartmentType());
		assertFalse(sct1.isConditionTrue(0, 0));
		
		assertFalse(sct1.equals(null));
		assertFalse(sct1.equals(new ConstantFunction()));
		
		assertTrue(sct1.equals(sct1));
		assertEquals(sct1.hashCode(), sct1.hashCode());
		assertTrue(sct1.equals(sct2));
		assertEquals(sct1.hashCode(), sct2.hashCode());
		
		sct1 = new ScheduledCompartmentType(new MockCondition(false), new DiscreteCompartmentType("type"));		
		assertFalse(sct1.equals(sct2));
		
		sct1 = new ScheduledCompartmentType(new MockCondition(true), new DiscreteCompartmentType("type2"));
		assertFalse(sct1.equals(sct2));
	}

	public void testConstructor() throws Exception{
		
		try {
			new ScheduledCompartmentType(new MockCondition(true), null);
			fail("An exception should have been thrown.");
		} catch (IllegalArgumentException e) {
			// we are supposed to be here
		}
		
		try {
			new ScheduledCompartmentType(null, new DiscreteCompartmentType("type"));
			fail("An exception should have been thrown.");
		} catch (IllegalArgumentException e) {
			// we are supposed to be here
		}
		
	}
	
	public void testToString(){
		String expected = "ScheduledCompartmentType [condition=MockCondition, compartmentType=DiscreteCompartmentType [name=123, possibleEventActions=[]] ]";
		assertEquals(expected, sct1.toString());
	}
	
}
