/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.conditions;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.conditions.Condition;
import de.fhstralsund.catsit.support.functions.ConstantFunction;

public class TestAbstractCondition extends TestCase{


	public void testEqualsAndHashCode() {
		Condition c1 = new MockCondition(Condition.GREATER_EQUALS);
		Condition c2 = new MockCondition(Condition.LESSER);
		
		assertFalse(c1.equals(null));
		assertFalse(c1.equals(new ConstantFunction()));
		assertFalse(c1.equals(c2));
		
		assertTrue(c1.equals(c1));
		assertTrue(c1.equals(new MockCondition(Condition.GREATER_EQUALS)));
		
		assertEquals(c1.hashCode(), new MockCondition(Condition.GREATER_EQUALS).hashCode());
		assertEquals(c2.hashCode(), new MockCondition(Condition.LESSER).hashCode());
	}

	public void testValueOf() {
		assertEquals(Condition.GREATER_EQUALS, Condition.valueOf(">="));
		assertEquals(Condition.GREATER_EQUALS, Condition.valueOf("GREATER_EQUALS"));
		assertEquals(Condition.LESSER, Condition.valueOf("<"));
		assertEquals(Condition.LESSER, Condition.valueOf("LESSER"));
		assertEquals(-1, Condition.valueOf("123"));
	}
	
}
