/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.conditions;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.conditions.Condition;
import de.fhstralsund.catsit.base.conditions.SizeCondition;
import de.fhstralsund.catsit.base.conditions.TimeCondition;
import de.fhstralsund.catsit.support.functions.ConstantFunction;

public class TestTimeCondition extends TestCase {

	public void testIsConditionTrue() {
		
		TimeCondition condition1 = new TimeCondition(Condition.GREATER_EQUALS, 10./60./24.);
		TimeCondition condition2 = new TimeCondition(Condition.LESSER, 10./60./24.);
		assertEquals(condition1.getCompareTime(), 10.0);
		
		assertTrue(condition1.isConditionTrue(10.0, 100));
		assertTrue(condition1.isConditionTrue(12.0, 100));
		assertFalse(condition1.isConditionTrue(9.9, 100));
		
		assertTrue(condition2.isConditionTrue(5.0, 100));
		assertFalse(condition2.isConditionTrue(10.0, 100));
		assertFalse(condition2.isConditionTrue(13.0, 100));
		
		//test with an unknown compare value
		TimeCondition condition3 = new TimeCondition(4, 100);
		assertFalse(condition3.isConditionTrue(1.0, 105));
	}

	public void testEquals(){
		TimeCondition condition = new TimeCondition(Condition.GREATER_EQUALS, 100);
		
		assertFalse(condition.equals(null));
		assertFalse(condition.equals(new ConstantFunction()));
		assertFalse(condition.equals(new TimeCondition(Condition.LESSER, 100)));
		assertFalse(condition.equals(new TimeCondition(Condition.LESSER, 101)));
		assertFalse(condition.equals(new TimeCondition(Condition.GREATER_EQUALS, 101)));
		assertFalse(condition.equals(new SizeCondition(Condition.GREATER_EQUALS, 100)));
		
		assertTrue(condition.equals(condition));
		assertTrue(condition.equals(new TimeCondition(Condition.GREATER_EQUALS, 100)));
	}
	
	public void testHashCode() {
		TimeCondition condition = new TimeCondition(Condition.GREATER_EQUALS, 100);

		assertFalse(condition.hashCode() == new ConstantFunction().hashCode());
		assertFalse(condition.hashCode() == new TimeCondition(Condition.LESSER, 100).hashCode());
		assertFalse(condition.hashCode() == new TimeCondition(Condition.LESSER, 101).hashCode());
		assertFalse(condition.hashCode() == new TimeCondition(Condition.GREATER_EQUALS, 101).hashCode());
		assertFalse(condition.hashCode() == new SizeCondition(Condition.GREATER_EQUALS, 100).hashCode());
		
		assertTrue(condition.hashCode() == condition.hashCode());
		assertTrue(condition.hashCode() == new TimeCondition(Condition.GREATER_EQUALS, 100).hashCode());
	}
	
	public void testToString(){
		TimeCondition condition = new TimeCondition(Condition.GREATER_EQUALS, 100/60./24.);
		assertEquals("time>=100.0", condition.toString());

		condition = new TimeCondition(Condition.LESSER, 100/60./24.);
		assertEquals("time<100.0", condition.toString());

		condition = new TimeCondition(Condition.GREATER_EQUALS, 101/60./24.);
		assertEquals("time>=101.0", condition.toString());
		
		//test with an unknown compare value
		condition = new TimeCondition(4, 100/60./24.);
		assertEquals("time?100.0", condition.toString());
	}
}
