/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.distribution;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.distributions.UniformDistribution;
import de.fhstralsund.catsit.support.functions.ConstantFunction;

public class TestUniformDistribution extends TestCase {
	private static final int MAX_LOOPS = 10000;
	
	public void testUniformDistribution() {
		try {
			new UniformDistribution(3, 2);
			fail("An IllegalArgumentException should have been thrown.");
		} catch (IllegalArgumentException e) {
			// we should be here
		}
		
		try {
			new UniformDistribution(3, 3);
			fail("An IllegalArgumentException should have been thrown.");
		} catch (IllegalArgumentException e) {
			// we should be here
		}
	
	}
	
	public void testGetDouble() {
		double minGiven = -2.;
		double maxGiven = 5.;
		UniformDistribution distri = new UniformDistribution(minGiven, maxGiven);
		double sum = 0;
		double min;
		double max;
		min = max = distri.getDouble();
		
		for (int i=1; i<MAX_LOOPS; i++) {
			double rand = distri.getDouble();
			sum += rand;
			if (min > rand) min = rand;
			if (max < rand) max = rand;
		}
		
		assertTrue(minGiven<=min);
		assertTrue(maxGiven>=max);
		assertEquals( minGiven+(maxGiven-minGiven)/2. , sum/MAX_LOOPS , 0.07);
	}

	public void testEquals(){
		UniformDistribution dis = new UniformDistribution(-3, 7.);
		
		assertFalse(dis.equals(null));
		assertFalse(dis.equals(new ConstantFunction()));
		assertFalse(dis.equals(new UniformDistribution(-3, 7.1)));
		assertFalse(dis.equals(new UniformDistribution(-3.4, 7.)));
		assertFalse(dis.equals(new UniformDistribution(3, 7.)));
		assertFalse(dis.equals(new UniformDistribution(-3, -1)));
		
		assertTrue(dis.equals(dis));
		assertTrue(dis.equals(new UniformDistribution(-3, 7.)));
	}
	
	public void testHashCode() {
		UniformDistribution dis = new UniformDistribution(-3, 7.);
		

		assertFalse(dis.hashCode() == new ConstantFunction().hashCode());
		assertFalse(dis.hashCode() == new UniformDistribution(-3, 7.1).hashCode());
		assertFalse(dis.hashCode() == new UniformDistribution(-3.4, 7.).hashCode());
		assertFalse(dis.hashCode() == new UniformDistribution(3, 7.).hashCode());
		assertFalse(dis.hashCode() == new UniformDistribution(-3, -1).hashCode());
		
		assertTrue(dis.hashCode() == dis.hashCode());
		assertTrue(dis.hashCode() == new UniformDistribution(-3, 7.).hashCode());
	}
	
	public void testToString(){		
		UniformDistribution dis = new UniformDistribution(-3, 7.);
		assertEquals("UniformDistribution [min=-3.0, interval=10.0]", dis.toString());

		dis = new UniformDistribution(-3.4, 7.9);
		assertEquals("UniformDistribution [min=-3.4, interval=11.3]", dis.toString());

		dis = new UniformDistribution(-3, -1);
		assertEquals("UniformDistribution [min=-3.0, interval=2.0]", dis.toString());
	}
}
