/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.eventactions;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.distributions.UniformDistribution;
import de.fhstralsund.catsit.base.eventactions.GenerationInfo;
import de.fhstralsund.catsit.support.functions.ConstantFunction;

/**
 * @author Anja Bethge
 *
 */
public class TestGenerationInfo extends TestCase {

	private GenerationInfo generationInfo1;
	private GenerationInfo generationInfo2;
	private GenerationInfo generationInfo3;
	

	protected final void setUp() throws Exception {
		generationInfo1 = new GenerationInfo(1.0, new ConstantFunction(), new MockDistribution());
		generationInfo2 = new GenerationInfo(0.34, new ConstantFunction(0.5), new MockDistribution());
		generationInfo3 = new GenerationInfo(0.98, new ConstantFunction(342.96), new MockDistribution());
	}

	
	public void testConstructor() {
		try {
			new GenerationInfo(-1, new ConstantFunction(), new MockDistribution());
			fail("An expection should have been thrown");
		} catch (IllegalArgumentException e) {
			// we are supposed to be here
		}
		
		try {
			new GenerationInfo(1, null, new MockDistribution());
			fail("An expection should have been thrown");
		} catch (IllegalArgumentException e) {
			// we are supposed to be here
		}
		
		try {
			new GenerationInfo(1, new ConstantFunction(), null);
			fail("An expection should have been thrown");
		} catch (IllegalArgumentException e) {
			// we are supposed to be here
		}
		
		GenerationInfo gi = new GenerationInfo(1.0, new ConstantFunction(), new MockDistribution());
		assertEquals(new ConstantFunction(), gi.getMeanTimeToNextEventFunction());
		assertTrue(gi.getDistribution() instanceof MockDistribution);
	}

	public void testGetProbability() {
		assertEquals(1.0, generationInfo1.getProbability());
		assertEquals(0.34, generationInfo2.getProbability());
		assertEquals(0.98, generationInfo3.getProbability());
	}
	
	public void testComputeTimeToThisEvent() {
		assertEquals(1.0, generationInfo1.computeTimeToThisEvent(5));
		assertEquals(0.5, generationInfo2.computeTimeToThisEvent(5));
		assertEquals(342.96, generationInfo3.computeTimeToThisEvent(5));
	}

	
	public void testToString() {
//		String expected = "GenerationInfo [probability=1.0, meanTimeToNextEvent=ConstantFunction [returnValue=1.0], distribution=MockDistribution]";
//		assertEquals(expected, generationInfo1.toString());
//		
//		expected = "GenerationInfo [probability=0.34, meanTimeToNextEvent=ConstantFunction [returnValue=0.5], distribution=MockDistribution]";
//		assertEquals(expected, generationInfo2.toString());
//		
//		expected = "GenerationInfo [probability=0.98, meanTimeToNextEvent=ConstantFunction [returnValue=342.96], distribution=MockDistribution]";
//		assertEquals(expected, generationInfo3.toString());
	}
	
	public void testEquals(){
		generationInfo1 = new GenerationInfo(1.0, new ConstantFunction(), new UniformDistribution(1, 2));
		generationInfo2 = new GenerationInfo(0.34, new ConstantFunction(0.5),new UniformDistribution(1, 2));
		generationInfo3 = new GenerationInfo(1.0, new ConstantFunction(), new UniformDistribution(1, 6));

		assertFalse(generationInfo1.equals(null));
		assertFalse(generationInfo1.equals(new ConstantFunction()));
		assertFalse(generationInfo1.equals(generationInfo2));
		assertFalse(generationInfo1.equals(generationInfo3));
		assertFalse(generationInfo1.equals(new GenerationInfo(1.0, new ConstantFunction(5), new UniformDistribution(1, 2))));
		assertFalse(generationInfo1.equals(new GenerationInfo(0.5, new ConstantFunction(), new UniformDistribution(1, 2))));
		
		
		assertTrue(generationInfo1.equals(generationInfo1));
		assertTrue(generationInfo1.equals(new GenerationInfo(1.0, new ConstantFunction(), new UniformDistribution(1, 2))));
	}
	
	public void testHashCode() {
		generationInfo1 = new GenerationInfo(1.0, new ConstantFunction(), new UniformDistribution(1, 2));
		generationInfo2 = new GenerationInfo(0.34, new ConstantFunction(0.5),new UniformDistribution(1, 2));
		generationInfo3 = new GenerationInfo(0.98, new ConstantFunction(342.96), new UniformDistribution(1, 2));
		
		assertEquals(generationInfo1.hashCode(), new GenerationInfo(1.0, new ConstantFunction(), new UniformDistribution(1, 2)).hashCode());
		assertEquals(generationInfo2.hashCode(), new GenerationInfo(0.34, new ConstantFunction(0.5), new UniformDistribution(1, 2)).hashCode());
		assertEquals(generationInfo3.hashCode(), new GenerationInfo(0.98, new ConstantFunction(342.96), new UniformDistribution(1, 2)).hashCode());
	}

}
