/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.eventactions.globaleventactions;

import de.fhstralsund.catsit.base.CompartmentInventory;
import de.fhstralsund.catsit.base.DiscreteCompartment;
import de.fhstralsund.catsit.base.Event;
import de.fhstralsund.catsit.base.LocalEvent;
import de.fhstralsund.catsit.base.MetastaseException;
import de.fhstralsund.catsit.base.eventactions.globaleventactions.RadioTherapy;
import de.fhstralsund.catsit.base.eventactions.globaleventactions.mockobjects.MockContinuousCompartment;
import de.fhstralsund.catsit.base.eventactions.globaleventactions.mockobjects.MockDiscreteCompartment;
import de.fhstralsund.catsit.base.eventactions.globaleventactions.mockobjects.MockRadioTherapy;
import de.fhstralsund.catsit.base.eventactions.localeventactions.AddCellToDiscreteCompartment;
import de.fhstralsund.catsit.base.eventactions.localeventactions.CellDeath;
import de.fhstralsund.catsit.base.eventactions.localeventactions.CellDivision;
import de.fhstralsund.catsit.base.treatments.TreatmentList;
import de.fhstralsund.catsit.machine.EventList;
import junit.framework.TestCase;

public class TestAbstractRadioTherapy extends TestCase {

	protected void setUp() throws Exception {
		CompartmentInventory.reset();
		CompartmentInventory.resetCompartmentCounter();
		EventList.reset();
		TreatmentList.reset();
	}
	
	@Override
	protected void tearDown() throws Exception {
		CompartmentInventory.reset();
		CompartmentInventory.resetCompartmentCounter();
		EventList.reset();
		TreatmentList.reset();
	}
	
	public void testHandleDiscreteCompartment() throws MetastaseException{
		DiscreteCompartment dc = new MockDiscreteCompartment();
		DiscreteCompartment dc2 = new MockDiscreteCompartment();
		
		dc.setNumberOfCells(500000);
		dc.setDormant(true);
		dc.setInLateDormancy(true);
		
		CellDivision cellDivision = new CellDivision("1", null);
		CellDeath cellDeath = new CellDeath("2", null);
		AddCellToDiscreteCompartment addCell = new AddCellToDiscreteCompartment("3", new MockContinuousCompartment());
		
		Event e1 = new LocalEvent(cellDivision, 1, dc);
		Event e2 = new LocalEvent(cellDivision, 2, dc2);
		Event e3 = new LocalEvent(cellDeath, 3, dc);
		Event e4 = new LocalEvent(cellDeath, 4, dc2);
		Event e5 = new LocalEvent(addCell, 5, dc);
		Event e6 = new LocalEvent(addCell, 6, dc2);
		
		EventList eventList = EventList.getInstance();
		eventList.addEvent(e1);
		eventList.addEvent(e2);
		eventList.addEvent(e3);
		eventList.addEvent(e4);
		eventList.addEvent(e5);
		eventList.addEvent(e6);
		
		RadioTherapy eventAction = new MockRadioTherapy();
		
		eventAction.handleDiscreteCompartment(dc, 200, 0.2);
		assertEquals(200, dc.getNumberOfCells(0));
		
		//dc events should all be deleted from the events, except for the addcell event
		assertEquals(e2, eventList.nextEvent());
		assertEquals(e4, eventList.nextEvent());
		assertEquals(e5, eventList.nextEvent());
		assertEquals(e6, eventList.nextEvent());
		
		assertTrue(eventList.isEmpty());
		
		//add all events again
		eventList.addEvent(e1);
		eventList.addEvent(e2);
		eventList.addEvent(e3);
		eventList.addEvent(e4);
		eventList.addEvent(e5);
		eventList.addEvent(e6);
		
		//kill of the compartment
		eventAction.handleDiscreteCompartment(dc, 0, 0.);
		
		assertEquals(0, dc.getNumberOfCells(0));
		assertFalse(dc.isDormant());
		assertFalse(dc.isInLateDormancy());
		
		//this time, also the add cell event should be deleted from the list
		assertEquals(e2, eventList.nextEvent());
		assertEquals(e4, eventList.nextEvent());
		assertEquals(e6, eventList.nextEvent());
		
		assertTrue(eventList.isEmpty());
	}

}
