/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.eventactions.globaleventactions;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.CompartmentInventory;
import de.fhstralsund.catsit.base.ContinuousCompartment;
import de.fhstralsund.catsit.base.DiscreteCompartment;
import de.fhstralsund.catsit.base.Event;
import de.fhstralsund.catsit.base.LocalEvent;
import de.fhstralsund.catsit.base.MetastaseException;
import de.fhstralsund.catsit.base.eventactions.globaleventactions.ExternalBeamRadiation;
import de.fhstralsund.catsit.base.eventactions.globaleventactions.GlobalEventAction;
import de.fhstralsund.catsit.base.eventactions.globaleventactions.mockobjects.MockContinuousCompartment;
import de.fhstralsund.catsit.base.eventactions.globaleventactions.mockobjects.MockDiscreteCompartment;
import de.fhstralsund.catsit.base.eventactions.globaleventactions.mockobjects.MockExternalBeamTreatment;
import de.fhstralsund.catsit.base.eventactions.localeventactions.AddCellToDiscreteCompartment;
import de.fhstralsund.catsit.base.eventactions.localeventactions.CellDivision;
import de.fhstralsund.catsit.base.treatments.TreatmentList;
import de.fhstralsund.catsit.machine.EventList;

public class TestExternalBeamRadiation extends TestCase {

	protected void setUp() throws Exception {
		CompartmentInventory.reset();
		CompartmentInventory.resetCompartmentCounter();
		EventList.reset();
		TreatmentList.reset();
	}

	@Override
	protected void tearDown() throws Exception {
		CompartmentInventory.reset();
		CompartmentInventory.resetCompartmentCounter();
		EventList.reset();
		TreatmentList.reset();
	}
	
	public void testExecute() throws MetastaseException{
		
		DiscreteCompartment dc = new MockDiscreteCompartment(true);
		DiscreteCompartment dc2 = new MockDiscreteCompartment(true);
		DiscreteCompartment dc3 = new MockDiscreteCompartment(false);
		ContinuousCompartment cc = new MockContinuousCompartment(true);
		ContinuousCompartment cc2 = new MockContinuousCompartment(false);
		
		dc.setNumberOfCells(10000);
		dc2.setNumberOfCells(0);
		dc3.setNumberOfCells(10000);
		
		CellDivision cellDivision = new CellDivision("1", null);
		AddCellToDiscreteCompartment addCell = new AddCellToDiscreteCompartment("3", cc);
		
		Event e1 = new LocalEvent(cellDivision, 1, dc);
		Event e2 = new LocalEvent(cellDivision, 2, dc2);
		Event e3 = new LocalEvent(cellDivision, 3, dc3);
		Event e4 = new LocalEvent(addCell, 4, dc);
		Event e5 = new LocalEvent(addCell, 5, dc2);
		Event e6 = new LocalEvent(addCell, 6, dc3);
		
		EventList eventList = EventList.getInstance();
		eventList.addEvent(e1);
		eventList.addEvent(e2);
		eventList.addEvent(e3);
		eventList.addEvent(e4);
		eventList.addEvent(e5);
		eventList.addEvent(e6);
		
		
		assertEquals(10000, dc.getNumberOfCells(100));
		assertEquals(0, dc2.getNumberOfCells(100));
		assertEquals(10000, dc3.getNumberOfCells(100));
		assertEquals(100, cc.getNumberOfCells(100)); //the mock compartment has a linear function as growth function x=1t+0
		assertEquals(100, cc2.getNumberOfCells(100));
		
		GlobalEventAction eventAction = new ExternalBeamRadiation("name", new MockExternalBeamTreatment());
		eventAction.execute(150);
		
		assertEquals(20, dc.getNumberOfCells(100));	//the  MockExternalBeamTreatment always returns 20 cells for computeNumberOfSurvivingCells
		assertEquals(0, dc2.getNumberOfCells(100));
		assertEquals(10000, dc3.getNumberOfCells(100)); // no primary => no change
		assertEquals(100, cc.getNumberOfCells(100)); 	// no discrete compartment => no change
		assertEquals(100, cc2.getNumberOfCells(100)); 	// no discrete compartment => no change
		
		assertEquals(e2, eventList.nextEvent()); //dc2's event should still be in the list, since dead compartment aren't handled by the event
		assertEquals(e3, eventList.nextEvent());
		assertEquals(e4, eventList.nextEvent());
		assertEquals(e5, eventList.nextEvent());
		assertEquals(e6, eventList.nextEvent());
		
		assertTrue(eventList.isEmpty());
		
		
	}
	
}
