/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.eventactions.globaleventactions;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.eventactions.globaleventactions.GlobalEventAction;
import de.fhstralsund.catsit.base.eventactions.globaleventactions.PrintStatus;
import de.fhstralsund.catsit.base.mockobjects.MockGlobalEventAction;
import de.fhstralsund.catsit.support.functions.ConstantFunction;

public class TestGlobalEventAction extends TestCase {

	public void testEquals(){
		GlobalEventAction gea = new MockGlobalEventAction("123");
		assertEquals("123", gea.getName());
		
		assertFalse(gea.equals(null));
		assertFalse(gea.equals(new ConstantFunction()));
		assertFalse(gea.equals(new MockGlobalEventAction("321")));
		
		assertTrue(gea.equals(gea));
		assertTrue(gea.equals(new MockGlobalEventAction("123")));
		
		gea = new MockGlobalEventAction(null);
		assertNull(gea.getName());
		
		assertTrue(gea.equals(new MockGlobalEventAction(null)));
		assertFalse(gea.equals(new MockGlobalEventAction("123")));
	}
	
	public void testHashCode() {
		GlobalEventAction gea = new MockGlobalEventAction("123");
		assertEquals(gea.hashCode(), new MockGlobalEventAction("123").hashCode());
		
		gea = new MockGlobalEventAction(null);
		assertEquals(gea.hashCode(), new MockGlobalEventAction(null).hashCode());
	}
	
	public void testToString(){
		GlobalEventAction gea = new MockGlobalEventAction("123");
		assertEquals("GlobalEventAction [name=123]", gea.toString());

		gea = new PrintStatus("311", null, null, null, null);
		assertEquals("GlobalEventAction [name=311]", gea.toString());

	}
}
