/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.eventactions.globaleventactions;

import java.util.ArrayList;
import java.util.List;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.CompartmentInventory;
import de.fhstralsund.catsit.base.DiscreteCompartment;
import de.fhstralsund.catsit.base.HostOrgan;
import de.fhstralsund.catsit.base.MetastaseException;
import de.fhstralsund.catsit.base.eventactions.globaleventactions.PrintStatus;
import de.fhstralsund.catsit.base.eventactions.globaleventactions.mockobjects.MockCompartment;
import de.fhstralsund.catsit.base.eventactions.globaleventactions.mockobjects.MockDiscreteCompartment;
import de.fhstralsund.catsit.base.eventactions.globaleventactions.mockobjects.MockExcelWriter;
import de.fhstralsund.catsit.base.eventactions.globaleventactions.mockobjects.MockHostOrgan;
import de.fhstralsund.catsit.base.treatments.TreatmentList;
import de.fhstralsund.catsit.io.excel.writer.ExcelRecordMain;
import de.fhstralsund.catsit.machine.EventList;
import de.fhstralsund.catsit.support.LogSampleHistogram;

public class TestPrintStatus extends TestCase {

	protected void setUp() throws Exception {
		CompartmentInventory.reset();
		CompartmentInventory.resetCompartmentCounter();
		EventList.reset();
		TreatmentList.reset();
	}

	@Override
	protected void tearDown() throws Exception {
		CompartmentInventory.reset();
		CompartmentInventory.resetCompartmentCounter();
		EventList.reset();
		TreatmentList.reset();
	}
	
	public void testExecute(){
		try {
						
			List<HostOrgan> organList = new ArrayList<HostOrgan>();
			organList.add(new MockHostOrgan("liver"));
			organList.add(new MockHostOrgan("lung"));
			
			MockExcelWriter ew = new MockExcelWriter(organList);
			MockCompartment primary = new MockCompartment();
			DiscreteCompartment blood = new MockDiscreteCompartment();
			
			primary.setNumberOfCells(1);
			
			PrintStatus ps = new PrintStatus("print status", primary, blood, organList, ew);		
			ps.execute(0);
			
			primary.setNumberOfCells(2000);
			ps.execute(2880);
			
			primary.setNumberOfCells(300000);
			blood.setNumberOfCells(27);
			ps.execute(2567520);
				
			assertEquals(3, ew.getBufferSize());
			
			ExcelRecordMain er1 = new ExcelRecordMain(0, 0, 1, 0, 0, 0, new LogSampleHistogram(12, 10));
			ExcelRecordMain er2 = new ExcelRecordMain(2880, 2, 2000, 0, 0,0, new LogSampleHistogram(12, 10));
			ExcelRecordMain er3 = new ExcelRecordMain(2567520, 1783, 300000, 27, 0,0, new LogSampleHistogram(12, 10));;
			
			assertEquals(er1, ew.getRecord(0));
			assertEquals(er2, ew.getRecord(1));
			assertEquals(er3, ew.getRecord(2));
			
			
			MockCompartment meta1 = new MockCompartment(new MockHostOrgan("lung"));
			MockCompartment meta2 = new MockCompartment(new MockHostOrgan("lung"));
			MockCompartment meta3 = new MockCompartment(new MockHostOrgan("lung"));
		
			meta1.setNumberOfCells(400);
			meta2.setNumberOfCells(34);
			meta3.setNumberOfCells(0);
			
			ps.execute(2880);
			
			LogSampleHistogram histogram = new LogSampleHistogram(12, 10);
			histogram.add(400);
			histogram.add(34);			
			er1 = new ExcelRecordMain(2880, 2, 300000, 27, 2, 434, histogram);			
			assertEquals(er1, ew.getRecord(3));
			
			meta3.setNumberOfCells(3000);
			ps.execute(2880);			
			histogram.add(3000);			
			er1 = new ExcelRecordMain(2880, 2, 300000, 27, 3, 3434, histogram);			
			assertEquals(er1, ew.getRecord(4));
			
		} catch (MetastaseException e) {
			e.printStackTrace();
			fail("unexpected exception");			
		}
	}
	
}
