/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.eventactions.globaleventactions.mockobjects;

import de.fhstralsund.catsit.base.ContinuousCompartment;
import de.fhstralsund.catsit.base.Event;
import de.fhstralsund.catsit.base.LocalEvent;
import de.fhstralsund.catsit.base.MetastaseException;
import de.fhstralsund.catsit.base.eventactions.localeventactions.AddCellToDiscreteCompartment;
import de.fhstralsund.catsit.support.functions.Function;
import de.fhstralsund.catsit.support.functions.LinearFunction;

public class MockContinuousCompartment extends ContinuousCompartment {

	public MockContinuousCompartment() throws MetastaseException {
		super(0., "mock", new MockHostOrgan(), new LinearFunction(1 *60.*24., 0), null);
	}
	
	public MockContinuousCompartment(boolean primary) throws MetastaseException {
		super(0., "mock", new MockHostOrgan(), new LinearFunction(1 *60.*24., 0), null, primary);
	}
	
	public MockContinuousCompartment(Function growthFunction) throws MetastaseException {
		super(0., "mock", new MockHostOrgan(), growthFunction, null);
	}
	
	@Override
	public void createNextEvent(double time) {
		//create the event and add it to the event list
		AddCellToDiscreteCompartment addCell = new AddCellToDiscreteCompartment("add cell", this);
		addCell.setTimeOfLastExecutedEventAction(time);
		Event e = new LocalEvent(addCell, time+300, getSuccessor());
		getEventList().addEvent(e);
	}
}
