/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.eventactions.globaleventactions.mockobjects;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import de.fhstralsund.catsit.base.HostOrgan;
import de.fhstralsund.catsit.io.excel.writer.ExcelRecordMain;
import de.fhstralsund.catsit.io.excel.writer.ExcelRecordSingleHostOrgan;
import de.fhstralsund.catsit.io.excel.writer.ExcelWriter;

public class MockExcelWriter extends ExcelWriter {
	
	private List<ExcelRecordMain> buffer;
	private Map<String, List<ExcelRecordSingleHostOrgan>> organBuffers;

	
	public MockExcelWriter(List<HostOrgan> organs) {
		super(organs);
		buffer = new ArrayList<ExcelRecordMain>();
		organBuffers = new HashMap<String, List<ExcelRecordSingleHostOrgan>>();
	}

	@Override
	public void bufferMainRecord(ExcelRecordMain record) {
		buffer.add(record);
	}
	
	@Override
	public void bufferHostOrganRecord(String organName, ExcelRecordSingleHostOrgan record){
		organBuffers.get(organName).add(record);
	}
	
	public ExcelRecordMain getRecord(int index){
		return buffer.get(index);
	}
	
	public int getBufferSize(){
		return buffer.size();
	}

	@Override
	public boolean isSheetNameAvailable(String filePath, String sheetName){		
		return true;
	}

	@Override
	public void writeAllBuffers(String filePath, String sheetName){
		//do nothing
	}

	
}
