/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.eventactions.localeventactions;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.distributions.GaussianDistribution;
import de.fhstralsund.catsit.base.distributions.UniformDistribution;
import de.fhstralsund.catsit.base.eventactions.GenerationInfo;
import de.fhstralsund.catsit.base.eventactions.localeventactions.CellProgressionEventAction;
import de.fhstralsund.catsit.base.eventactions.localeventactions.mockobjects.MockCellProgressionAction;
import de.fhstralsund.catsit.machine.EventList;
import de.fhstralsund.catsit.support.functions.ConstantFunction;

public class TestCellProgressionEventAction extends TestCase {

	@Override
	protected void setUp() throws Exception {
		EventList.reset();
	}
	
	public void testIt(){
		CellProgressionEventAction cpea = new MockCellProgressionAction("a1", new GenerationInfo(0.5, new ConstantFunction(), new UniformDistribution(5, 10)));
		
		assertEquals(0.5, cpea.getProbability());
		assertEquals(new UniformDistribution(5, 10), cpea.getDistribution());
		assertEquals(new ConstantFunction(), cpea.getMeanTimeToNextEventFunction());		
		
		assertEquals("name=a1, genererationInfo=GenerationInfo [probability=0.5, meanTimeToNextEvent=ConstantFunction [returnValue=1.0], " +
				"distribution=UniformDistribution [min=5.0, interval=5.0]]", 
				cpea.toString());
		
		cpea = new MockCellProgressionAction("a1", new GenerationInfo(0.5, new ConstantFunction(), new GaussianDistribution(1, 0)));
		assertEquals(1.0, cpea.computeTimeToThisEvent(10));
	}
	
	public void testEqualsAndHashCode(){
		CellProgressionEventAction cpea = new MockCellProgressionAction("a1", 0.5);
		
		assertFalse(cpea.equals(null));
		assertFalse(cpea.equals(new ConstantFunction()));
		assertFalse(cpea.hashCode() == new ConstantFunction().hashCode());
		assertFalse(cpea.equals(new MockCellProgressionAction("a2", 0.5)));
		assertFalse(cpea.hashCode() == new MockCellProgressionAction("a2", 0.5).hashCode());
		assertFalse(cpea.equals(new MockCellProgressionAction("a1", 0.4)));
		assertFalse(cpea.hashCode() == new MockCellProgressionAction("a1", 0.4).hashCode());
		
		assertTrue(cpea.equals(cpea));
		assertTrue(cpea.hashCode() == cpea.hashCode());
		assertTrue(cpea.equals(new MockCellProgressionAction("a1", 0.5)));
		assertTrue(cpea.hashCode() == new MockCellProgressionAction("a1", 0.5).hashCode());
		
		cpea = new MockCellProgressionAction("a1", null);
		assertFalse(cpea.equals(new MockCellProgressionAction("a1", 0.4)));
		assertFalse(cpea.hashCode() == new MockCellProgressionAction("a1", 0.4).hashCode());
		
		assertTrue(cpea.equals(new MockCellProgressionAction("a1", null)));
		assertTrue(cpea.hashCode() == new MockCellProgressionAction("a1", null).hashCode());
		
	}
}
