/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.eventactions.localeventactions;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.Compartment;
import de.fhstralsund.catsit.base.ContinuousCompartment;
import de.fhstralsund.catsit.base.MetastaseException;
import de.fhstralsund.catsit.base.eventactions.localeventactions.StartLateDormancy;
import de.fhstralsund.catsit.base.eventactions.localeventactions.mockobjects.MockHostOrgan;
import de.fhstralsund.catsit.base.mockobjects.MockDiscreteCompartment;
import de.fhstralsund.catsit.support.functions.ConstantFunction;

public class TestStartLateDormancy extends TestCase {

	
	public void testIt() throws MetastaseException{
		
		Compartment compartment = new ContinuousCompartment(0, "x", new MockHostOrgan(), new ConstantFunction(0), null);
		assertFalse(compartment.isInLateDormancy());
		
		StartLateDormancy eventAction = new StartLateDormancy();			
		
		//If the compartment is already dead (has 0 cells) the dormancy event should be ignored
		eventAction.execute(compartment, 0.0);			
		assertFalse(compartment.isInLateDormancy());
		
		//if the compartment is not dead it should be dormant after the execution of the event
		compartment = new ContinuousCompartment(0, "x", new MockHostOrgan(), new ConstantFunction(3), null);
		eventAction.execute(compartment, 1.0);			
		assertTrue(compartment.isInLateDormancy());
		
		//now, try to execute the event with a wrong compartment type
		try {
			eventAction.execute(new MockDiscreteCompartment(), 1.0);
			fail("An IllegalArgumentException should have been thrown.");
		} catch (IllegalArgumentException e) {
			// everything is just fine
		}
	}
	
}
