/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.eventactions.localeventactions;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.DiscreteCompartment;
import de.fhstralsund.catsit.base.MetastaseException;
import de.fhstralsund.catsit.base.eventactions.localeventactions.StopLateDormancy;
import de.fhstralsund.catsit.base.mockobjects.MockDiscreteCompartment;

public class TestStopLateDormancy extends TestCase {

	public void testIt() {
		try{
			DiscreteCompartment compartment = new MockDiscreteCompartment();
			compartment.setNumberOfCells(20);
			compartment.setInLateDormancy(true);
			assertTrue(compartment.isInLateDormancy());
			
			StopLateDormancy eventAction = new StopLateDormancy();
			eventAction.execute(compartment, 0.0);
			
			assertFalse(compartment.isInLateDormancy());
			
			assertEquals("StopLateDormancy [name=stop late dormancy]", eventAction.toString());
		} catch (MetastaseException e) {
			e.printStackTrace();
			fail("unexpected exeption");
		}
	}
}
