/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.eventactions.localeventactions;


import junit.framework.TestCase;
import de.fhstralsund.catsit.base.ContinuousCompartment;
import de.fhstralsund.catsit.base.LocalEvent;
import de.fhstralsund.catsit.base.MetastaseException;
import de.fhstralsund.catsit.base.eventactions.localeventactions.AddCellToDiscreteCompartment;
import de.fhstralsund.catsit.base.eventactions.localeventactions.StopDormancy;
import de.fhstralsund.catsit.base.eventactions.localeventactions.mockobjects.MockContinuousCompartment;
import de.fhstralsund.catsit.base.eventactions.localeventactions.mockobjects.MockHostOrgan;
import de.fhstralsund.catsit.machine.EventList;
import de.fhstralsund.catsit.support.functions.ColonizationRate;
import de.fhstralsund.catsit.support.functions.ConstantFunction;
import de.fhstralsund.catsit.support.functions.LinearFunction;

public class TestStopTumorDormancy extends TestCase {

	@Override
	protected void setUp() throws Exception {
		EventList.reset();
	}
	
	public void testIt() throws MetastaseException{
		
		EventList eventList = EventList.getInstance();
		ContinuousCompartment compartment = new MockContinuousCompartment(new ConstantFunction(0), new ColonizationRate(1, 0.6));
		
		compartment.setDormant(true);
		assertTrue(compartment.isDormant());
		
		StopDormancy eventAction = new StopDormancy();		
		eventAction.execute(compartment, 0.0);
		assertFalse(compartment.isDormant());
		
		//if the tumor is dead no event should have been added to the list
		assertTrue(eventList.isEmpty());
		
		compartment = new ContinuousCompartment(0., "mock", new MockHostOrgan(), new LinearFunction(1, 1), new ColonizationRate(1, 0.6));
		eventAction.execute(compartment, 0.0);
		
		assertFalse(compartment.isDormant());
		assertTrue(((LocalEvent)eventList.nextEvent()).getEventAction() instanceof AddCellToDiscreteCompartment);
		assertTrue(eventList.isEmpty());
		
		
		assertEquals("StopDormancy [name=stop dormancy]", eventAction.toString());
	}
}
