/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.eventactions.localeventactions;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.Compartment;
import de.fhstralsund.catsit.base.CompartmentInventory;
import de.fhstralsund.catsit.base.ContinuousCompartment;
import de.fhstralsund.catsit.base.DiscreteCompartment;
import de.fhstralsund.catsit.base.DiscreteCompartmentType;
import de.fhstralsund.catsit.base.LocalEvent;
import de.fhstralsund.catsit.base.MetastaseException;
import de.fhstralsund.catsit.base.eventactions.localeventactions.CellProgressionEventAction;
import de.fhstralsund.catsit.base.eventactions.localeventactions.TransferToNextCompartment;
import de.fhstralsund.catsit.base.eventactions.localeventactions.mockobjects.MockCellProgressionAction;
import de.fhstralsund.catsit.base.eventactions.localeventactions.mockobjects.MockContinuousCompartment;
import de.fhstralsund.catsit.base.eventactions.localeventactions.mockobjects.MockHostOrgan;
import de.fhstralsund.catsit.machine.EventList;

public class TestTransferToNextCompartment extends TestCase {

	@Override
	protected void setUp() throws Exception {
		CompartmentInventory.reset();
		CompartmentInventory.resetCompartmentCounter();
		EventList.reset();
	}
	
	public void testExecute() throws MetastaseException{
			
		EventList eventList = EventList.getInstance();
		
		//create the compartment type and the discrete compartment, that is needed for the execute-method
		DiscreteCompartmentType compartmentType = new DiscreteCompartmentType("sample discrete type");
		compartmentType.addPossibleEventAction(new MockCellProgressionAction());
		
		DiscreteCompartment compartment1 = new DiscreteCompartment(0, new MockHostOrgan(), compartmentType);
		DiscreteCompartment successor = new DiscreteCompartment(0, new MockHostOrgan(), compartmentType);
		compartment1.setSuccessor(successor);
		int numberOfCells = 10;
		for (int i=0; i<numberOfCells; i++) {
			compartment1.addCell(0);
			successor.addCell(0);
		}
		assertEquals(numberOfCells, compartment1.getNumberOfCells(0));
		assertEquals(numberOfCells, successor.getNumberOfCells(0));
		
		
		TransferToNextCompartment eventAction = new TransferToNextCompartment("event action", null);
		
		
		eventAction.execute((Compartment)compartment1, 0.);
		//one cell has had to be deleted from compartment 1
		assertEquals(numberOfCells-1, compartment1.getNumberOfCells(0.));
		//one cell has had to be added to the successor compartment
		assertEquals(numberOfCells+1, successor.getNumberOfCells(0.));
		//no new compartment should have been registered
		assertEquals(2, CompartmentInventory.getCompartments().size());
		
		//a new event should have been created by the successor compartment;
		assertTrue(((LocalEvent)eventList.nextEvent()).getEventAction() instanceof CellProgressionEventAction);
		assertTrue(eventList.isEmpty());
		
		//now, try to execute the event with a wrong compartment type
		ContinuousCompartment cc = new MockContinuousCompartment();
		try {
			eventAction.execute(cc, 1.0);
			fail("An IllegalArgumentException should have been thrown.");
		} catch (IllegalArgumentException e) {
			// everything is just fine
		}

	}

}
