/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.treatments;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.treatments.InternalRadiationTreatment;
import de.fhstralsund.catsit.base.treatments.TreatmentList;
import de.fhstralsund.catsit.support.functions.ConstantFunction;

public class TestAbstractInternalRadiationTreatment extends TestCase {

	protected void setUp() throws Exception {
		TreatmentList.reset();
	}
	
	@Override
	protected void tearDown() throws Exception {
		TreatmentList.reset();
	}
	
	public void testGetters(){
		InternalRadiationTreatment irt = new MockInternalRadiationTreatment(1, 2, 3, 4, 5);
		
		assertEquals(1., irt.getAlpha());
		assertEquals(2., irt.getBeta());
		assertEquals(3., irt.getActivity());
		assertEquals(4., irt.getEnergy());
		assertEquals(5., irt.getHalflife());
	}
	
	public void testToString(){
		InternalRadiationTreatment irt = new MockInternalRadiationTreatment(1, 2, 3, 4, 5);
		assertEquals("alpha=1.0, beta=2.0, activity=3.0, energy=4.0, halflife=5.0", irt.toString());
	}
	
	public void testEqualsAndHashCode(){
		InternalRadiationTreatment irt = new MockInternalRadiationTreatment(1, 2, 3, 4, 5);
		InternalRadiationTreatment irt2 = new MockInternalRadiationTreatment(1, 2, 3, 4, 5);
		
		assertEquals(irt, irt);
		assertEquals(irt.hashCode(), irt.hashCode());
		
		assertEquals(irt, irt2);		
		assertEquals(irt.hashCode(), irt2.hashCode());
		
		assertFalse(irt.equals(new MockInternalRadiationTreatment(2, 2, 3, 4, 5)));
		assertFalse(irt.hashCode() == new MockInternalRadiationTreatment(2, 2, 3, 4, 5).hashCode());
		assertFalse(irt.equals(new MockInternalRadiationTreatment(1, 3, 3, 4, 5)));
		assertFalse(irt.hashCode() == new MockInternalRadiationTreatment(1, 3, 3, 4, 5).hashCode());
		assertFalse(irt.equals(new MockInternalRadiationTreatment(1, 2, 4, 4, 5)));
		assertFalse(irt.hashCode() == new MockInternalRadiationTreatment(1, 2, 4, 4, 5).hashCode());
		assertFalse(irt.equals(new MockInternalRadiationTreatment(1, 2, 3, 5, 5)));
		assertFalse(irt.hashCode() == new MockInternalRadiationTreatment(1, 2, 3, 5, 5).hashCode());
		assertFalse(irt.equals(new MockInternalRadiationTreatment(1, 2, 3, 4, 6)));
		assertFalse(irt.hashCode() == new MockInternalRadiationTreatment(1, 2, 3, 4, 6).hashCode());
		
		assertFalse(irt.equals(new ConstantFunction()));
		assertFalse(irt.hashCode() == new ConstantFunction().hashCode());
		
		assertFalse(irt.equals(null));
	}


}
