/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.treatments;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.treatments.RadiationTreatment;
import de.fhstralsund.catsit.base.treatments.TreatmentList;
import de.fhstralsund.catsit.support.functions.ConstantFunction;

public class TestAbstractRadiationTreatment extends TestCase {

	protected void setUp() throws Exception {
		TreatmentList.reset();
	}
	
	@Override
	protected void tearDown() throws Exception {
		TreatmentList.reset();
	}
	
	public void testGetters(){
		RadiationTreatment rt = new MockRadiationTreatment(1, 2);
		
		assertEquals(1., rt.getAlpha());
		assertEquals(2., rt.getBeta());
	}
	
	public void testToString(){
		RadiationTreatment rt = new MockRadiationTreatment(1, 2);
		assertEquals("alpha=1.0, beta=2.0", rt.toString());
	}
	
	public void testEqualsAndHashCode(){
		RadiationTreatment rt = new MockRadiationTreatment(1, 2);
		RadiationTreatment rt2 = new MockRadiationTreatment(1, 2);
		
		assertEquals(rt, rt);
		assertEquals(rt.hashCode(), rt.hashCode());
		assertEquals(rt2, rt2);
		assertEquals(rt2.hashCode(), rt2.hashCode());
		
		assertEquals(rt, rt2);		
		assertEquals(rt.hashCode(), rt2.hashCode());
		
		assertFalse(rt.equals(new MockRadiationTreatment(2, 2)));
		assertFalse(rt.hashCode() == new MockRadiationTreatment(2, 2).hashCode());
		assertFalse(rt.equals(new MockRadiationTreatment(1, 3)));
		assertFalse(rt.hashCode() == new MockRadiationTreatment(1, 3).hashCode());
		
		assertFalse(rt.equals(new ConstantFunction()));
		assertFalse(rt.hashCode() == new ConstantFunction().hashCode());
		
		assertFalse(rt.equals(null));
	}


}
