/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.treatments;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.treatments.ExternalBeamTreatment;
import de.fhstralsund.catsit.base.treatments.TreatmentList;
import de.fhstralsund.catsit.support.functions.ConstantFunction;

public class TestExternalBeamTreatment extends TestCase {

	protected void setUp() throws Exception {
		TreatmentList.reset();
	}
	
	@Override
	protected void tearDown() throws Exception {
		TreatmentList.reset();
	}
	
	public void testGetters(){
		ExternalBeamTreatment ebt = new ExternalBeamTreatment(1, 2, 3);
		
		assertEquals(1., ebt.getAlpha());
		assertEquals(2., ebt.getBeta());
	}
	
	public void testComputeNumberOfSurvivingCells(){
		ExternalBeamTreatment ebt = new ExternalBeamTreatment(0.4, 0.02, 5);
		
		assertEquals(0, ebt.computeNumberOfSurvivingCells(1));
		assertEquals(0, ebt.computeNumberOfSurvivingCells(10));
		assertEquals(8, ebt.computeNumberOfSurvivingCells(100));
		assertEquals(82, ebt.computeNumberOfSurvivingCells(1000));
		assertEquals(273, ebt.computeNumberOfSurvivingCells(3333));
		assertEquals(4560, ebt.computeNumberOfSurvivingCells(55555));
		assertEquals(10133950, ebt.computeNumberOfSurvivingCells(123456789));
	}
	
	public void testToString(){
		ExternalBeamTreatment ebt = new ExternalBeamTreatment(1, 2, 3);
		assertEquals("ExternalBeamTreatment [alpha=1.0, beta=2.0, dose=3.0]", ebt.toString());
	}
	
	public void testEqualsAndHashCode(){
		ExternalBeamTreatment ebt = new ExternalBeamTreatment(1, 2, 3);
		ExternalBeamTreatment ebt2 = new ExternalBeamTreatment(1, 2, 3);
		
		assertEquals(ebt, ebt);
		assertEquals(ebt.hashCode(), ebt.hashCode());
		
		assertEquals(ebt, ebt2);		
		assertEquals(ebt.hashCode(), ebt2.hashCode());
		
		assertFalse(ebt.equals(new ExternalBeamTreatment(2, 2, 3)));
		assertFalse(ebt.hashCode() == new ExternalBeamTreatment(2, 2, 3).hashCode());
		assertFalse(ebt.equals(new ExternalBeamTreatment(1, 3, 3)));
		assertFalse(ebt.hashCode() == new ExternalBeamTreatment(1, 3, 3).hashCode());
		assertFalse(ebt.equals(new ExternalBeamTreatment(1, 2, 4)));
		assertFalse(ebt.hashCode() == new ExternalBeamTreatment(1, 2, 4).hashCode());
		
		assertFalse(ebt.equals(new ConstantFunction()));
		assertFalse(ebt.hashCode() == new ConstantFunction().hashCode());
		
		assertFalse(ebt.equals(null));
	}

}
