/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.base.treatments;

import java.util.Iterator;

import de.fhstralsund.catsit.base.treatments.Treatment;
import de.fhstralsund.catsit.base.treatments.TreatmentList;
import de.fhstralsund.catsit.base.treatments.TreatmentList.TreatmentEntry;
import junit.framework.TestCase;

public class TestTreatmentList extends TestCase {

	protected void setUp() throws Exception {
		TreatmentList.reset();
	}
	
	@Override
	protected void tearDown() throws Exception {
		TreatmentList.reset();
	}
	
	public void testAddTreatment(){
		TreatmentList list = TreatmentList.getInstance();
		
		Treatment t1 = new MockTreatment();
		Treatment t2 = new MockTreatment();
		Treatment t3 = new MockTreatment();
		Treatment t4 = new MockTreatment();
		Treatment t5 = new MockTreatment();
		
		list.addTreatment(50 /60./24., t1);
		list.addTreatment(10 /60./24., t2);
		list.addTreatment(12 /60./24., t3);
		list.addTreatment(60 /60./24., t4);
		list.addTreatment(61 /60./24., t5);
		list.addTreatment(61 /60./24., t1);
		list.addTreatment(61 /60./24., t2);
		
		Iterator<TreatmentEntry> it = list.iterator();
		
		TreatmentEntry entry = it.next();
		assertEquals(10., entry.time);
		assertSame(t2, entry.treatment);
		
		entry = it.next();
		assertEquals(12., entry.time);
		assertSame(t3, entry.treatment);
		
		entry = it.next();
		assertEquals(50., entry.time);
		assertSame(t1, entry.treatment);
		
		entry = it.next();
		assertEquals(60., entry.time);
		assertSame(t4, entry.treatment);
		
		entry = it.next();
		assertEquals(61., entry.time);
		assertSame(t5, entry.treatment);
		
		entry = it.next();
		assertEquals(61., entry.time);
		assertSame(t1, entry.treatment);
		
		entry = it.next();
		assertEquals(61., entry.time);
		assertSame(t2, entry.treatment);
		
		assertFalse(it.hasNext());
		
		try {
			list.addTreatment(0, t1);
			fail("An exception should have been thrown.");
		} catch (IllegalArgumentException e) {
			assertEquals("The time must be bigger than 0 but was 0.0.", e.getMessage());
		}
		
		try {
			list.addTreatment(-2, t1);
			fail("An exception should have been thrown.");
		} catch (IllegalArgumentException e) {
			assertEquals("The time must be bigger than 0 but was -2.0.", e.getMessage());
		}
		
		try {
			list.addTreatment(5, null);
			fail("An exception should have been thrown.");
		} catch (IllegalArgumentException e) {
			assertEquals("The Treatment must no be null.", e.getMessage());
		}
	}

}
