/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.io.excel;

import junit.framework.TestCase;
import de.fhstralsund.catsit.io.excel.writer.ExcelRecordMain;
import de.fhstralsund.catsit.support.LogSampleHistogram;
import de.fhstralsund.catsit.support.functions.ConstantFunction;

public class TestExcelRecordMain extends TestCase {

	public void testIt(){
		
		try {
			new ExcelRecordMain(-1, 1, 1, 1, 1, 1, new LogSampleHistogram(10, 10));
			fail("An exception should have been thrown.");
		} catch (IllegalArgumentException e) {
			// we are supposed to be here
		}
		
		try {
			new ExcelRecordMain(1, -1, 1, 1, 1, 1, new LogSampleHistogram(10, 10));
			fail("An exception should have been thrown.");
		} catch (IllegalArgumentException e) {
			// we are supposed to be here
		}
		
		try {
			new ExcelRecordMain(1, 1, -1, 1, 1, 1, new LogSampleHistogram(10, 10));
			fail("An exception should have been thrown.");
		} catch (IllegalArgumentException e) {
			// we are supposed to be here
		}
		
		try {
			new ExcelRecordMain(1, 1, 1, -1, 1, 1, new LogSampleHistogram(10, 10));
			fail("An exception should have been thrown.");
		} catch (IllegalArgumentException e) {
			// we are supposed to be here
		}
		
		try {
			new ExcelRecordMain(1, 1, 1, 1, -1, 1, new LogSampleHistogram(10, 10));
			fail("An exception should have been thrown.");
		} catch (IllegalArgumentException e) {
			// we are supposed to be here
		}
		
		try {
			new ExcelRecordMain(1, 1, 1, 1, 1, -1, new LogSampleHistogram(10, 10));
			fail("An exception should have been thrown.");
		} catch (IllegalArgumentException e) {
			// we are supposed to be here
		}
		
		ExcelRecordMain mainRecord = new ExcelRecordMain(1, 1, 1, 1, 1, 1, new LogSampleHistogram(10, 10));
		assertEquals(1, mainRecord.getTime());
		assertEquals(1.0, mainRecord.getTimeInDays());
		assertEquals(1, mainRecord.getCellsInPrimaryTumor());
		assertEquals(1, mainRecord.getCellsInBloodStream());
		assertEquals(1, mainRecord.getNumberMetastases());
		assertEquals(1, mainRecord.getCellsInMetastases());
		assertEquals(new LogSampleHistogram(10, 10), mainRecord.getHistogram());
	}
	
	public void testEqualsAndHashCode(){
		
		ExcelRecordMain mainRecord = new ExcelRecordMain(1, 1, 1, 1, 1, 1, new LogSampleHistogram(10, 10));
		
		assertTrue(mainRecord.equals(mainRecord));
		assertTrue(mainRecord.hashCode() == mainRecord.hashCode());
		assertTrue(mainRecord.equals(new ExcelRecordMain(1, 1, 1, 1, 1, 1, new LogSampleHistogram(10, 10))));
		assertTrue(mainRecord.hashCode() == new ExcelRecordMain(1, 1, 1, 1, 1, 1, new LogSampleHistogram(10, 10)).hashCode());
		
		assertFalse(mainRecord.equals(null));
		assertFalse(mainRecord.equals(new ConstantFunction()));
		assertFalse(mainRecord.hashCode() == new ConstantFunction().hashCode());
		
		assertFalse(mainRecord.equals(new ExcelRecordMain(2, 1, 1, 1, 1, 1, new LogSampleHistogram(10, 10))));
		assertFalse(mainRecord.hashCode() == new ExcelRecordMain(2, 1, 1, 1, 1, 1, new LogSampleHistogram(10, 10)).hashCode());
		assertFalse(mainRecord.equals(new ExcelRecordMain(1, 2, 1, 1, 1, 1, new LogSampleHistogram(10, 10))));
		assertFalse(mainRecord.hashCode() == new ExcelRecordMain(1, 2, 1, 1, 1, 1, new LogSampleHistogram(10, 10)).hashCode());
		assertFalse(mainRecord.equals(new ExcelRecordMain(1, 1, 2, 1, 1, 1, new LogSampleHistogram(10, 10))));
		assertFalse(mainRecord.hashCode() == new ExcelRecordMain(1, 1, 2, 1, 1, 1, new LogSampleHistogram(10, 10)).hashCode());
		assertFalse(mainRecord.equals(new ExcelRecordMain(1, 1, 1, 2, 1, 1, new LogSampleHistogram(10, 10))));
		assertFalse(mainRecord.hashCode() == new ExcelRecordMain(1, 1, 1, 2, 1, 1, new LogSampleHistogram(10, 10)).hashCode());
		assertFalse(mainRecord.equals(new ExcelRecordMain(1, 1, 1, 1, 2, 1, new LogSampleHistogram(10, 10))));
		assertFalse(mainRecord.hashCode() == new ExcelRecordMain(1, 1, 1, 1, 2, 1, new LogSampleHistogram(10, 10)).hashCode());
		assertFalse(mainRecord.equals(new ExcelRecordMain(1, 1, 1, 1, 1, 2, new LogSampleHistogram(10, 10))));
		assertFalse(mainRecord.hashCode() == new ExcelRecordMain(1, 1, 1, 1, 1, 2, new LogSampleHistogram(10, 10)).hashCode());
		assertFalse(mainRecord.equals(new ExcelRecordMain(1, 1, 1, 1, 1, 1, new LogSampleHistogram(20, 10))));
		assertFalse(mainRecord.hashCode() == new ExcelRecordMain(1, 1, 1, 1, 1, 1, new LogSampleHistogram(20, 10)).hashCode());
		
		mainRecord = new ExcelRecordMain(1, 1, 1, 1, 1, 1, null);
		assertFalse(mainRecord.equals(new ExcelRecordMain(1, 1, 1, 1, 1, 1, new LogSampleHistogram(10, 10))));
		assertFalse(mainRecord.hashCode() == new ExcelRecordMain(1, 1, 1, 1, 1, 1, new LogSampleHistogram(10, 10)).hashCode());
		assertTrue(mainRecord.equals(new ExcelRecordMain(1, 1, 1, 1, 1, 1, null)));
		assertTrue(mainRecord.hashCode() == new ExcelRecordMain(1, 1, 1, 1, 1, 1, null).hashCode());
	}
	
}
