/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.io.xml;

import java.util.Iterator;
import java.util.logging.Level;
import java.util.logging.Logger;

import junit.framework.TestCase;
import de.fhstralsund.catsit.io.xml.ReferenceMap;
import de.fhstralsund.catsit.io.xml.ReferenceMap.RefType;
import de.fhstralsund.catsit.support.functions.ConstantFunction;

/**
 * Tests the {@link ReferenceMap}
 * 
 * @author Michael Suhr
 * 
 */
public class TestReferenceMap extends TestCase {

    private ReferenceMap refMap = new ReferenceMap();

    @Override
    protected final void setUp() throws Exception {
        super.setUp();
        Logger.getLogger("metastase.support.xml").setLevel(Level.WARNING);
    }

    public void testAddToEmptyList() {
        assertEquals(0, refMap.keySize());
        refMap.add("blood", RefType.FUNCTION, new ConstantFunction(1));
        assertEquals(1, refMap.keySize());
        assertTrue(refMap.keySet().contains("blood;function"));
        assertEquals(1, refMap.size());
    }

    public void testAddToList() {
        refMap.add("blood", RefType.FUNCTION, new ConstantFunction(1));
        assertEquals(1, refMap.get("blood;function").size());
        refMap.add("blood", RefType.FUNCTION, new ConstantFunction(2));
        assertEquals(1, refMap.keySize());
        assertEquals(2, refMap.get("blood;function").size());
        assertEquals(2, refMap.size());
    }

    public void testAddToTwoLists() {
        refMap.add("blood", RefType.FUNCTION, new ConstantFunction(1));
        assertEquals(1, refMap.get("blood;function").size());
        refMap.add("lymph", RefType.FUNCTION, new ConstantFunction(2));
        assertEquals(2, refMap.keySize());
        assertEquals(1, refMap.get("blood;function").size());
        assertEquals(1, refMap.get("lymph;function").size());
        assertEquals(2, refMap.size());
    }

    public void testSizeCalculation() {
        refMap.add("blood", RefType.FUNCTION, new ConstantFunction(1));
        refMap.add("blood", RefType.FUNCTION, new ConstantFunction(3));
        assertEquals(2, refMap.get("blood;function").size());
        refMap.add("lymph", RefType.FUNCTION, new ConstantFunction(2));
        assertEquals(2, refMap.keySize());
        assertEquals(2, refMap.get("blood;function").size());
        assertEquals(1, refMap.get("lymph;function").size());
        assertEquals(3, refMap.size());
    }

    public void testIterator() {
        refMap.add("blood", RefType.FUNCTION, new ConstantFunction(1));
        refMap.add("blood", RefType.FUNCTION, new ConstantFunction(2));
        refMap.add("lymph", RefType.FUNCTION, new ConstantFunction(3));
        Iterator<Object> it1 = refMap.iterator("blood;function");
        int count = 0;
        while (it1.hasNext()) {
            count++;
            it1.next();
        }
        assertEquals(2, count);
    }

}
