/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.io.xml.builder;

import java.util.logging.Level;
import java.util.logging.Logger;

import junit.framework.TestCase;

import org.w3c.dom.Element;

import de.fhstralsund.catsit.base.distributions.Distribution;
import de.fhstralsund.catsit.base.distributions.GaussianDistribution;
import de.fhstralsund.catsit.base.distributions.UniformDistribution;
import de.fhstralsund.catsit.io.xml.MockParser;
import de.fhstralsund.catsit.io.xml.ObjectBuffer;
import de.fhstralsund.catsit.io.xml.builder.DistributionBuilder;


/**
 * Tests the {@link DistributionBuilder}.
 * 
 * @author Michael
 * 
 */
public class TestDistributionBuilder extends TestCase {

    private final ObjectBuffer maps = new ObjectBuffer();

    String exponential = "<gaussianDistribution distID=\"normal\">" + "<stdDev>20</stdDev>" + "<mean>60</mean>"
            + "</gaussianDistribution>";

    String uniform = "<uniformDistribution distID=\"treated\">" + "<min>10</min>" + "<max>15</max>"
            + "</uniformDistribution>";

    @Override
    protected final void setUp() throws Exception {
        super.setUp();
        Logger.getLogger("metastase.support.xml").setLevel(Level.WARNING);
    }

    public void testExponentialDistribution() {
        Element doc = MockParser.parseString(exponential);

        Distribution expected = new GaussianDistribution(60, 20);
        Distribution dis = DistributionBuilder.parse(doc, maps);
        assertTrue(dis instanceof GaussianDistribution);
        assertEquals(expected.toString(), dis.toString());
    }

    public void testUniformDistribution() {
        Element doc = MockParser.parseString(uniform);

        Distribution expected = new UniformDistribution(10, 15);
        Distribution dis = DistributionBuilder.parse(doc, maps);
        assertTrue(dis instanceof UniformDistribution);
        assertEquals(expected.toString(), dis.toString());
    }

}
