/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.io.xml.builder;

import org.w3c.dom.Element;

import de.fhstralsund.catsit.base.HostOrgan;
import de.fhstralsund.catsit.base.distributions.Distribution;
import de.fhstralsund.catsit.base.distributions.GaussianDistribution;
import de.fhstralsund.catsit.io.xml.MockParser;
import de.fhstralsund.catsit.io.xml.ObjectBuffer;
import de.fhstralsund.catsit.io.xml.ParserException;
import de.fhstralsund.catsit.io.xml.builder.HostOrganBuilder;
import junit.framework.TestCase;

public class TestHostOrganBuilder extends TestCase {

	public void testParse() throws ParserException{
		
		ObjectBuffer maps = new ObjectBuffer();
		
		String xml = "<hostOrgan organID=\"organ\"> <name>organ</name> </hostOrgan>";
		HostOrgan expectedOrgan = new HostOrgan("organ", false);
		
		Element doc = MockParser.parseString(xml);
		HostOrgan organ = HostOrganBuilder.parse(doc, maps);
		
		assertEquals(expectedOrgan, organ);
		
		//with printHostOrgan
		xml = "<hostOrgan organID=\"organ\"> <name>organ</name> <printHostOrgan>true</printHostOrgan> </hostOrgan>";
		expectedOrgan = new HostOrgan("organ", true);
		
		doc = MockParser.parseString(xml);
		organ = HostOrganBuilder.parse(doc, maps);
		
		assertEquals(expectedOrgan, organ);
		
		//with dormancy
		xml = "<hostOrgan organID=\"organ\"> <name>organ</name> <dormancy distRef=\"dormancy\"/> <printHostOrgan>true</printHostOrgan> </hostOrgan>";
		doc = MockParser.parseString(xml);
		
		try {
			//try parsing the host organ a missing reference for the dormancy
			organ = HostOrganBuilder.parse(doc, maps);
			fail("An exception should have been thrown!");
			
		} catch (ParserException e) {
			assertEquals("Could not find the Distribution with id: dormancy. Maybe a misspelling?", e.getMessage());
		}
		
		//put the dormancy distribution into the map
		Distribution dormancy = new GaussianDistribution(5, 2);
		maps.putDistribution("dormancy", dormancy);	
		
		expectedOrgan = new HostOrgan("organ", dormancy, true);
		organ = HostOrganBuilder.parse(doc, maps);
		assertEquals(expectedOrgan, organ);
		
		//with late dormancy		
		xml = "<hostOrgan organID=\"organ\"> <name>organ</name> <lateDormancy><size distRef=\"dormancySize\"/> <duration distRef=\"dormancyDuration\"/> "
				+ "</lateDormancy> <printHostOrgan>true</printHostOrgan> </hostOrgan>";
		doc = MockParser.parseString(xml);
		
		try {
			//try parsing the host organ a missing reference for the dormancy size
			organ = HostOrganBuilder.parse(doc, maps);
			fail("An exception should have been thrown!");
			
		} catch (ParserException e) {
			assertEquals("Could not find the Distribution with id: dormancySize. Maybe a misspelling?", e.getMessage());
		}
		
		//add the dormancy size to the maps
		Distribution dormancySize = new GaussianDistribution(5, 2);
		maps.putDistribution("dormancySize", dormancySize);
		
		try {
			//try parsing the host organ a missing reference for the dormancy duration
			organ = HostOrganBuilder.parse(doc, maps);
			fail("An exception should have been thrown!");
			
		} catch (ParserException e) {
			assertEquals("Could not find the Distribution with id: dormancyDuration. Maybe a misspelling?", e.getMessage());
		}
		
		//put the dormancy duration to the maps
		Distribution dormancyDuration = new GaussianDistribution(100, 2);		
		maps.putDistribution("dormancyDuration", dormancyDuration);
		
		expectedOrgan = new HostOrgan("organ", null, dormancySize, dormancyDuration, true);	
		organ = HostOrganBuilder.parse(doc, maps);
		
		assertEquals(expectedOrgan, organ);
	}	
}
