/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.machine;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.Event;
import de.fhstralsund.catsit.machine.EventList;
import de.fhstralsund.catsit.machine.NoEventLeftException;

/**
 * @author Gero Wedemann
 *
 */
public abstract class TestAbstractEventList extends TestCase {
	private EventList eventList;
	
	public void testNoEvent() {
		assertTrue(eventList.isEmpty());
		try {
			eventList.nextEvent();
			fail("no NoEventLeftException thrown");
		}
		catch (NoEventLeftException e) {
			// we expected to be here ...
		}
	}
	
	/**
	 * Test method for {@link metastase.machine.eventlists.SimpleEventList#addEvent(metastase.base.Event)}.
	 */
	public void testSingleEvent()  {
		try {
			Event event0 = new MockGlobalEvent(5.);
			eventList.addEvent(event0);
			assertFalse(eventList.isEmpty());
			Event returnedEvent = eventList.nextEvent();
			assertEquals(event0, returnedEvent);
			assertTrue(eventList.isEmpty());
		}
		catch (NoEventLeftException e) {
			fail("wrong NoEventLeftException");
		}
	}

	public void testMultipleEvents(){
		Event event0 = new MockGlobalEvent(7.);
		Event event1 = new MockGlobalEvent(5.);
		Event event2 = new MockGlobalEvent(6.5);
		eventList.addEvent(event0);
		eventList.addEvent(event1);
		eventList.addEvent(event2);
		try {
			assertEquals(event1, eventList.nextEvent());
			assertEquals(event2, eventList.nextEvent());
			assertEquals(event0, eventList.nextEvent());
		}
		catch (NoEventLeftException e) {
			fail("wrong NoEventLeftException");
		}
		
		assertNotNull(eventList.iterator());
		
		eventList.addEvent(event0);
		eventList.addEvent(event1);
		eventList.addEvent(event2);
		assertEquals(event0, eventList.removeEvent(event0));
	}

	public void setEventList(EventList eventList) {
		this.eventList = eventList;
	}	

	public EventList getEventList() {
		return eventList;
	}

}
