/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.machine;

import java.util.ArrayList;
import java.util.List;

import de.fhstralsund.catsit.base.Event;
import de.fhstralsund.catsit.machine.EventList;
import de.fhstralsund.catsit.machine.NoEventLeftException;
import de.fhstralsund.catsit.machine.eventlists.HenriksenEventList;

public class TestHenriksenEventList extends TestAbstractEventList {

	@Override
	public void setUp() {
		EventList.reset();
		// set the deadline to 20 days
		HenriksenEventList elist = new HenriksenEventList();
		elist.setDeadline(20.0*60*24);
		setEventList(elist);
	}

	/**
	 * We have a vector in HenriksenList which is rebuild, if it is too small.
	 * We test this functionality by putting in many events. You have to change
	 * there: ARRAY_LENGTH_INIT = 2
	 * 
	 */
	public void testManyEvents() {
		double times[] = { 2., 1., 3., 4., 6., 14., 9., 12., 10., 11., 8., 7., 5., 13., 20., 17., 18., 19., 16., 15. };

		// add the 20 events and ...
		for (int i = 0; i < times.length; i++) {
			getEventList().addEvent(new MockGlobalEvent(times[i]));
		}
		// ... check, whether they were sorted in correct
		for (int i = 0; i < 20; i++) {
			try {
				assertEquals(i + 1., getEventList().nextEvent().getTime());
			} catch (NoEventLeftException e) {
				fail("no event left at i=" + i);
			}
		}
		assertTrue(getEventList().isEmpty());
		

		double times2[] = { 1., 2., 3., 5., 4., 10., 16., 18., 9., 7., 12.,	15., 10., 19., 20., 36., 25., 4., 14., 
				76., 44., (21.*24.*60.), 74., 25., 82., 85., 1.1 };

		// add the events and ...
		for (int i = 0; i < times2.length; i++) {
			getEventList().addEvent(new MockGlobalEvent(times2[i]));
		}

		try{
			// ... check, whether they were sorted in correct 
			//(21.*24.*60. should not be returned, since the time lies after the deadline of 20 days)
			assertEquals(1., getEventList().nextEvent().getTime());
			assertEquals(1.1, getEventList().nextEvent().getTime());
			assertEquals(2., getEventList().nextEvent().getTime());
			assertEquals(3., getEventList().nextEvent().getTime());
			assertEquals(4., getEventList().nextEvent().getTime());
			assertEquals(4., getEventList().nextEvent().getTime());
			assertEquals(5., getEventList().nextEvent().getTime());
			assertEquals(7., getEventList().nextEvent().getTime());
			assertEquals(9., getEventList().nextEvent().getTime());
			assertEquals(10., getEventList().nextEvent().getTime());
			assertEquals(10., getEventList().nextEvent().getTime());
			assertEquals(12., getEventList().nextEvent().getTime());
			assertEquals(14., getEventList().nextEvent().getTime());
			assertEquals(15., getEventList().nextEvent().getTime());
			assertEquals(16., getEventList().nextEvent().getTime());
			assertEquals(18., getEventList().nextEvent().getTime());
			assertEquals(19., getEventList().nextEvent().getTime());
			assertEquals(20., getEventList().nextEvent().getTime());
			assertEquals(25., getEventList().nextEvent().getTime());
			assertEquals(25., getEventList().nextEvent().getTime());
			assertEquals(36., getEventList().nextEvent().getTime());
			assertEquals(44., getEventList().nextEvent().getTime());
			assertEquals(74., getEventList().nextEvent().getTime());
			assertEquals(76., getEventList().nextEvent().getTime());
			assertEquals(82., getEventList().nextEvent().getTime());
			assertEquals(85., getEventList().nextEvent().getTime());
			
		}catch (NoEventLeftException e) {
			fail("no event left ");
			
		}
	}
	
	
	public void testRemoveEvent(){
		//just to test the default constructor
		setEventList(new HenriksenEventList());
		
		List<Event> tempList = new ArrayList<Event>();
		
		// add some events
		for (int i = 50; i > 0; i--) {
			Event e = new MockGlobalEvent(i);
			tempList.add(e);
			getEventList().addEvent(e);
		}
		
		
		//remove some events
		Event eventToRemove = tempList.remove(6);
		assertEquals(eventToRemove, getEventList().removeEvent(eventToRemove));
		
		eventToRemove = tempList.remove(2);
		assertEquals(eventToRemove, getEventList().removeEvent(eventToRemove));
		
		eventToRemove = tempList.remove(17);
		assertEquals(eventToRemove, getEventList().removeEvent(eventToRemove));
		
		eventToRemove = tempList.remove(42);
		assertEquals(eventToRemove, getEventList().removeEvent(eventToRemove));
		
		eventToRemove = tempList.remove(5);
		assertEquals(eventToRemove, getEventList().removeEvent(eventToRemove));
		
		//try to remove an event that does not exist in the list
		assertNull(getEventList().removeEvent(new MockGlobalEvent(2.7)));
		
		//add some events with the same time
		Event first = new MockGlobalEvent(3.5);
		getEventList().addEvent(new MockGlobalEvent(3.5));
		getEventList().addEvent(first);
		getEventList().addEvent(new MockGlobalEvent(3.5));
		getEventList().addEvent(new MockGlobalEvent(3.5));
		getEventList().addEvent(new MockGlobalEvent(3.5));
		
		assertEquals(first, getEventList().removeEvent(first));
		
		//try to remove an event with the same time that does not exist in the list
		assertNull(getEventList().removeEvent(new MockGlobalEvent(3.5)));
	}
}
