/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.machine;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.NoSuchElementException;

import junit.framework.TestCase;
import de.fhstralsund.catsit.base.Event;
import de.fhstralsund.catsit.machine.eventlists.HenriksenEventList;
import de.fhstralsund.catsit.machine.eventlists.HenriksenIterator;

public class TestHenriksenIterator extends TestCase {

	public void testHasNext() {
		HenriksenEventList list = new HenriksenEventList();
		Iterator<Event> i = list.iterator();

		assertNotNull(i);
		assertTrue(i instanceof HenriksenIterator);
		assertFalse(i.hasNext());

		for (Event event : list) {
			fail("We should not be here! The iterator seems to return the dummy entries.");
		}

		// add some events
		for (int j = 1; j < 20; j++) {
			list.addEvent(new MockGlobalEvent(j));
		}

		i = list.iterator();
		for (int j = 1; j < 20; j++) {
			assertTrue(i.hasNext());
			i.next();
		}
		// we already parsed all entries, so there should none be left
		assertFalse(i.hasNext());
	}

	public void testNext() {
		HenriksenEventList list = new HenriksenEventList();
		Iterator<Event> i = list.iterator();

		assertNotNull(i);
		assertTrue(i instanceof HenriksenIterator);
		try {
			i.next();
			fail("we shouldn't be here");
		} catch (NoSuchElementException e) {
			// we should be here
		}

		// temp list, which holds all events added to the henriksen list
		List<Event> events = new ArrayList<Event>();
		// add some events
		for (int j = 1; j < 54; j++) {
			Event e = new MockGlobalEvent(j);
			events.add(e);
			list.addEvent(e);
		}

		for (Event event : list) {
			// remove the returned event from the temp list
			events.remove(event);
		}

		// the temp list should be empty. If not, the iterator did not return
		// all events.
		assertEquals(0, events.size());
	}

	public void testRemove() {
		HenriksenEventList list = new HenriksenEventList();
		// add some events
		for (int j = 1; j < 9; j++) {
			list.addEvent(new MockGlobalEvent(j));
		}
		
		Iterator<Event> i = list.iterator();
		
		try {
			i.remove();
			fail("we shouldn't be here");
		} catch (UnsupportedOperationException e) {
			// we should be here
		}
	}
}
