/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support;

import junit.framework.TestCase;
import de.fhstralsund.catsit.support.HistogramEntry;
import de.fhstralsund.catsit.support.functions.ConstantFunction;

public class TestHistogrammEntry extends TestCase {

	
	public void testHistogramEntry() throws Exception{
		
		//check the constructor
		HistogramEntry entry = new HistogramEntry(1.0, 3.0);
		assertEquals(1.0, entry.getLowerLimit());
		assertEquals(3.0, entry.getUpperLimit());
		
		//check add
		try {
			entry.add(0.5);
			fail("An IllegalArgumentException should have been thrown!");
		} catch (IllegalArgumentException e) {/* everything is okay. we should be here*/}
		
		try {
			entry.add(3.0);
			fail("An IllegalArgumentException should have been thrown!");
		} catch (IllegalArgumentException e) {/* everything is okay. we should be here*/}
		
		try {
			entry.add(3.5);
			fail("An IllegalArgumentException should have been thrown!");
		} catch (IllegalArgumentException e) {/* everything is okay. we should be here*/}
		
		entry.add(2.5);
		assertEquals(2.5, entry.mean());
		
		
		//check isInLimits
		assertTrue(entry.isInLimits(2.0));
		assertTrue(entry.isInLimits(1.0));
		assertFalse(entry.isInLimits(3.0));
		assertFalse(entry.isInLimits(3.5));
		assertFalse(entry.isInLimits(0.5));
		
		//check equals
		assertTrue(entry.equals(entry));
		assertFalse(entry.equals(null));
		assertFalse(entry.equals(new ConstantFunction()));
		
		HistogramEntry entry2 = new HistogramEntry(1.0, 3.0);
		HistogramEntry entry3 = new HistogramEntry(2.0, 3.0);
		HistogramEntry entry4 = new HistogramEntry(1.0, 4.0);
		HistogramEntry entry5 = new HistogramEntry(0.0, 4.0);
		
		assertFalse(entry.equals(entry2));
		entry2.add(2.5);
		assertTrue(entry.equals(entry2));
		
		entry = new HistogramEntry(1.0, 3.0);
		assertFalse(entry.equals(entry3));
		assertFalse(entry.equals(entry4));
		assertFalse(entry.equals(entry5));
		
		//check the constructor
		try {
			entry = new HistogramEntry(3.0, 1.0);
			fail("An IllegalArgumentException should have been thrown!");
		} catch (IllegalArgumentException e) {
			// everything is okay. we should be here
		}
				
	}
	
	
}
