/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support;

import de.fhstralsund.catsit.support.HistogramEntry;
import de.fhstralsund.catsit.support.LogSampleHistogram;
import de.fhstralsund.catsit.support.SampleStatistic;
import junit.framework.TestCase;

public class TestLogSampleHistogram extends TestCase {
	
	
	public void testIt() throws Exception{
		int decades=3;
		int bucketsPerDecade=10;
		
		LogSampleHistogram lsh = new LogSampleHistogram(decades, bucketsPerDecade);
		//fill the buckets
		double decadestep = 0.1;
		for (double i=0; i<decades; i+=decadestep) {
			lsh.add(Math.pow(10,i)-0.1);
			
		}
		//add the value manually (does not work in the for-loop, because of rounding 
		//errors => it never reaches 3.0 only 2.9000000000000012)
		lsh.add(Math.pow(10, decades)-0.1);
		
		//add the last value manually
		lsh.add(Math.pow(10, decades)+0.1);
		
		//add one before the lowest limit (should not be added)
		lsh.add(-2.0);
		
		for (HistogramEntry he: lsh.getBuckets()) {
			assertEquals(1, he.getN());
		}
		
		try {
			lsh = new LogSampleHistogram(0, 10);
			fail("An exception should have been thrown, since decades is smaller 1!");
		} catch (Exception e) {
			//everything okay
		}
		
		try {
			lsh = new LogSampleHistogram(3, 0);
			fail("An exception should have been thrown, since bucketsPerDecade is smaller 1!");
		} catch (Exception e) {
			//everything okay
		}
		
		lsh = new LogSampleHistogram(decades, bucketsPerDecade);
		//test equals
		assertTrue(lsh.equals(lsh));
		assertTrue(lsh.equals(new LogSampleHistogram(decades, bucketsPerDecade)));
		
		assertFalse(lsh.equals(null));
		assertFalse(lsh.equals(new SampleStatistic()));
		assertFalse(lsh.equals(new LogSampleHistogram(50, bucketsPerDecade)));
		
		lsh.add(20); //change the buckets content
		assertFalse(lsh.equals(new LogSampleHistogram(decades, bucketsPerDecade)));
	}
} 
