/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support;

import junit.framework.TestCase;
import de.fhstralsund.catsit.support.SampleStatistic;
import de.fhstralsund.catsit.support.functions.ConstantFunction;

public class TestSampleStatistic extends TestCase {
	
	private static final double NUMERICAL_LIMIT = 0.0001;
	
	public void testIt() throws Exception{
		SampleStatistic s = new SampleStatistic();
		assertEquals(0., s.mean());
		assertEquals(0., s.stdDev());
		assertEquals(0., s.var());
		assertEquals(0, s.getN());
		
		//check equals
		assertTrue(s.equals(s));
		assertTrue(s.equals(new SampleStatistic()));
		assertFalse(s.equals(null));
		assertFalse(s.equals(new ConstantFunction()));
		
		SampleStatistic s2 = new SampleStatistic();
		//change max limit
		s2.add(0);
		s2.add(3);
		assertFalse(s.equals(s2));
		//change min limit
		s2.add(-1);
		assertFalse(s.equals(s2));		
		//change n
		s.add(-1);
		s.add(3);
		assertFalse(s.equals(s2));
		//change x
		s.add(2);
		assertFalse(s.equals(s2));
			
		
		//check var(), mean() and stDev()
		s = new SampleStatistic();
		s.add(3);
		assertEquals(0., s.var());
		assertEquals(0., s.stdDev());
		
		s.add(2);
		assertEquals(2.5, s.mean(), NUMERICAL_LIMIT);
		assertEquals(1./2., s.var(), NUMERICAL_LIMIT);
		assertEquals(1./Math.sqrt(2.), s.stdDev(), NUMERICAL_LIMIT);
		assertEquals(2, s.getN());
		
		s.add(-4);
		assertEquals(1./3., s.mean(), NUMERICAL_LIMIT);		
		

	}
	
	
}
