/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support.functions;

import de.fhstralsund.catsit.support.functions.ConstantFunction;
import de.fhstralsund.catsit.support.functions.ExponentialFunction;
import de.fhstralsund.catsit.support.functions.Function;
import junit.framework.TestCase;

public class TestConstantFunction extends TestCase {

	public void testF() {
		// ** data **
		double m = 0.;		
		ConstantFunction function = new ConstantFunction(m);
		assertEquals(0.0, function.getReturnValue());
				
		//check if the function yields the correct value 
		for (int i = 0; i < 1e+5; i++) {
			assertEquals("at step "+i, m, function.f(i));
		}
		
		m = 1.;		
		function = new ConstantFunction();
		assertEquals(1.0, function.getReturnValue());
				
		//check if the function yields the correct value 
		for (int i = 0; i < 1e+5; i++) {
			assertEquals("at step "+i, m, function.f(i));
		}
		
		m = -4.6;		
		function = new ConstantFunction(m);
		assertEquals(-4.6, function.getReturnValue());
				
		//check if the function yields the correct value 
		for (int i = 0; i < 1e+5; i++) {
			assertEquals("at step "+i, m, function.f(i));
		}
		
		m = 19452.94517;		
		function = new ConstantFunction(m);
				
		//check if the function yields the correct value 
		for (int i = 0; i < 1e+5; i++) {
			assertEquals("at step "+i, m, function.f(i));
		}

	}
	
	public void testF_FirstDerivation() {
		// ** data **
		double m = 0.;		
		Function function = new ConstantFunction(m);
		double correctValue = 0;
				
		//check if the Derivation yields the correct values 
		for (int i = 0; i < 1e+5; i++) {
			assertEquals("at step "+i, correctValue, function.f_FirstDerivation(i));
		}
		
		m = 5.;
		function = new ConstantFunction(m);
				
		//check if the Derivation yields the correct values 
		for (int i = 0; i < 1e+5; i++) {
			assertEquals("at step "+i, correctValue, function.f_FirstDerivation(i));
		}
		
		m = -5.742;
		function = new ConstantFunction(m);
				
		//check if the Derivation yields the correct values 
		for (int i = 0; i < 1e+5; i++) {
			assertEquals("at step "+i, correctValue, function.f_FirstDerivation(i));
		}
	}
	
	public void testToString() {
		Function function = new ConstantFunction(0);
		assertEquals("ConstantFunction [returnValue=0.0]", function.toString());
		
		function = new ConstantFunction(5);
		assertEquals("ConstantFunction [returnValue=5.0]", function.toString());
		
		function = new ConstantFunction(0.763);
		assertEquals("ConstantFunction [returnValue=0.763]", function.toString());
		
		function = new ConstantFunction(-98.0742);
		assertEquals("ConstantFunction [returnValue=-98.0742]", function.toString());		
	}

	public void testEquals() {
		Function function = new ConstantFunction(4.65);
		
		assertFalse(function.equals(null));
		assertFalse(function.equals(new ExponentialFunction(1, 2, 3)));
		assertFalse(function.equals(new ConstantFunction()));
		assertFalse(function.equals(new ConstantFunction(9)));
		assertFalse(function.equals(new ConstantFunction(-3.976)));
		assertFalse(function.equals(new ConstantFunction(97.975)));
		
		assertTrue(function.equals(function));
		assertTrue(function.equals(new ConstantFunction(4.65)));
		assertTrue(function.equals(new ConstantFunction(4.6500)));
		
		assertTrue(new ConstantFunction().equals(new ConstantFunction(1)));
	}
	
	public void testHashCode() {
		Function function = new ConstantFunction(0);
		assertEquals(629, function.hashCode());
		
		function = new ConstantFunction(5);
		assertEquals(1075053173, function.hashCode());
		
		function = new ConstantFunction(0.763);
		assertEquals(-969716956, function.hashCode());
		
		function = new ConstantFunction(-98.0742);
		assertEquals(1896076789, function.hashCode());
	}

}
