/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support.functions;

import de.fhstralsund.catsit.support.functions.chemo.LinearChemoFunction;
import junit.framework.TestCase;

public class TestFunctionUtil extends TestCase {

	
	public void testCopyGrowthFunctionWithNewStartSize(){
		
		ConstantFunction c1 = new ConstantFunction(50);
		assertEquals(new ConstantFunction(20), FunctionUtil.copyGrowthFunctionWithNewStartSize(c1, 20));
		
		LinearFunction l1 = new LinearFunction(0.5, 33);
		assertEquals(new LinearFunction(0.5, 99), FunctionUtil.copyGrowthFunctionWithNewStartSize(l1, 99));
		
		ExponentialFunction e1 = new ExponentialFunction(42, 0.6, 4);
		assertEquals(new ExponentialFunction(70, 0.6, 0), FunctionUtil.copyGrowthFunctionWithNewStartSize(e1, 70));
		e1 = new ExponentialFunction(45, 0.6, 0);
		assertEquals(new ExponentialFunction(78, 0.6, 0), FunctionUtil.copyGrowthFunctionWithNewStartSize(e1, 78));
		
		LogFunction l2 = new LogFunction(0.5, 0.8, 12);
		assertEquals(new LogFunction(0.5, 0.8, 23), FunctionUtil.copyGrowthFunctionWithNewStartSize(l2, 23));
		
		PowerFunction p1 = new PowerFunction(2, 0.5, 25);
		assertEquals(new PowerFunction(2, 0.5, 100), FunctionUtil.copyGrowthFunctionWithNewStartSize(p1, 100));

		GompertzFunction g1 = new GompertzFunction(0.5, 10000, 200);
		assertEquals(new GompertzFunction(0.5, 10000, 200), FunctionUtil.copyGrowthFunctionWithNewStartSize(g1, 200));
		
		assertNull(FunctionUtil.copyGrowthFunctionWithNewStartSize(new LinearChemoFunction(2, 20, 0.5, 0.9, 0.8), 50));
	}

}
