/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support.functions;

import de.fhstralsund.catsit.support.functions.ConstantFunction;
import de.fhstralsund.catsit.support.functions.Function;
import de.fhstralsund.catsit.support.functions.LinearFunction;
import junit.framework.TestCase;

public class TestLinearFunction extends TestCase {

	public void testF() {
		// ** data **
		double m = 5.;
		double n = 7.;		
		Function function = new LinearFunction(m, n);
				
		//check if the function yields the correct values 
		for (int i = 0; i < 1e+5; i++) {
			double correctValue = m*i+n;
			assertEquals("at step "+i, correctValue, function.f(i));
		}
		
		m = -5.4;
		n = 7.;		
		function = new LinearFunction(m, n);
				
		//check if the function yields the correct values 
		for (int i = 0; i < 1e+5; i++) {
			double correctValue = m*i+n;
			assertEquals("at step "+i, correctValue, function.f(i));
		}
		
		m = -5.4;
		n = -16.;		
		function = new LinearFunction(m, n);
				
		//check if the function yields the correct values 
		for (int i = 0; i < 1e+5; i++) {
			double correctValue = m*i+n;
			assertEquals("at step "+i, correctValue, function.f(i));
		}
		
		m = 35.4;
		n = -16.;		
		function = new LinearFunction(m, n);
				
		//check if the function yields the correct values 
		for (int i = 0; i < 1e+5; i++) {
			double correctValue = m*i+n;
			assertEquals("at step "+i, correctValue, function.f(i));
		}
	}

	
	public void testF_FirstDerivation() {
		// ** data **
		double m = 5.;
		double n = 7.;
		Function function = new LinearFunction(m, n);
				
		//check if the Derivation yields the correct values 
		for (int i = 0; i < 1e+5; i++) {
			double correctValue = m;
			assertEquals("at step "+i, correctValue, function.f_FirstDerivation(i));
		}
		
		m = -3.5;
		n = 7.56;
		function = new LinearFunction(m, n);
				
		//check if the Derivation yields the correct values 
		for (int i = 0; i < 1e+5; i++) {
			double correctValue = m;
			assertEquals("at step "+i, correctValue, function.f_FirstDerivation(i));
		}
		
		m = 354.5;
		n = -767.;
		function = new LinearFunction(m, n);
				
		//check if the Derivation yields the correct values 
		for (int i = 0; i < 1e+5; i++) {
			double correctValue = m;
			assertEquals("at step "+i, correctValue, function.f_FirstDerivation(i));
		}		
	}
	
	public void testToString() {
		Function function = new LinearFunction(7, 34);
		assertEquals("LinearFunction [7.0*x+34.0 ]", function.toString());
		
		function = new LinearFunction(-7, 34);
		assertEquals("LinearFunction [-7.0*x+34.0 ]", function.toString());
		
		function = new LinearFunction(7, 0.65);
		assertEquals("LinearFunction [7.0*x+0.65 ]", function.toString());
	}

	public void testEquals() {
		Function function = new LinearFunction(3, 76);
		
		assertFalse(function.equals(null));
		assertFalse(function.equals(new ConstantFunction()));
		assertFalse(function.equals(new LinearFunction(6, 76)));
		assertFalse(function.equals(new LinearFunction(3, -76)));
		assertFalse(function.equals(new LinearFunction(0.65, 763)));
		assertFalse(function.equals(new LinearFunction(-5, 0.652)));
		
		assertTrue(function.equals(function));
		assertTrue(function.equals(new LinearFunction(3, 76)));
		assertTrue(function.equals(new LinearFunction(3.0000, 76.00)));
	}
	
	public void testHashCode() {
		Function function = new LinearFunction(3, 76);
		
		assertFalse(function.hashCode() == new ConstantFunction().hashCode());
		assertFalse(function.hashCode() == new LinearFunction(6, 76).hashCode());
		assertFalse(function.hashCode() == new LinearFunction(3, -76).hashCode());
		assertFalse(function.hashCode() == new LinearFunction(0.65, 763).hashCode());
		assertFalse(function.hashCode() == new LinearFunction(-5, 0.652).hashCode());
		
		assertEquals(function.hashCode(), function.hashCode());
		assertEquals(function.hashCode(), new LinearFunction(3, 76).hashCode());
		assertEquals(function.hashCode(), new LinearFunction(3.0000, 76.00).hashCode());
		
	}

	public void testGetM() {
		LinearFunction function = new LinearFunction(7, 12);
		assertEquals(7, function.getM(), 0);
		
		function = new LinearFunction(8.76, 12);
		assertEquals(8.76, function.getM(), 0);
		
		function = new LinearFunction(-0.764, 12);
		assertEquals(-0.764, function.getM(), 0);
		
		function = new LinearFunction(2/3, 12);
		assertEquals(2/3, function.getM(), 0);
	}
	
	public void testGetN() {
		LinearFunction function = new LinearFunction(7, 12);
		assertEquals(12, function.getN(), 0);
		
		function = new LinearFunction(12, 8.76);
		assertEquals(8.76, function.getN(), 0);
		
		function = new LinearFunction(7, -0.764);
		assertEquals(-0.764, function.getN(), 0);
		
		function = new LinearFunction(7, 2/3);
		assertEquals(2/3, function.getN(), 0);	
	}
	
}
