/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support.functions;

import de.fhstralsund.catsit.support.functions.ConstantFunction;
import de.fhstralsund.catsit.support.functions.LinearFunction;
import de.fhstralsund.catsit.support.functions.NoNextSectionException;
import de.fhstralsund.catsit.support.functions.PiecewiseGrowthFunction;
import junit.framework.TestCase;

public class TestPiecewiseGrowthFunction extends TestCase {

	
	public void testGetFirstTimePoint(){
		PiecewiseGrowthFunction pieceWiseFunction = new PiecewiseGrowthFunction(0., new ConstantFunction(5));
		pieceWiseFunction.addFunction(20, new ConstantFunction());
		pieceWiseFunction.addFunction(50, new ConstantFunction());
		assertEquals(0., pieceWiseFunction.getFirstTimePoint());
		
		pieceWiseFunction = new PiecewiseGrowthFunction(20., new ConstantFunction(5));
		assertEquals(20., pieceWiseFunction.getFirstTimePoint());
		
		pieceWiseFunction = new PiecewiseGrowthFunction(1236579., new ConstantFunction(5));
		assertEquals(1236579., pieceWiseFunction.getFirstTimePoint());
	}
	
	public void testAddFunctionAndF(){
		PiecewiseGrowthFunction pieceWiseFunction = new PiecewiseGrowthFunction(0., new ConstantFunction(5));
		
		assertEquals(5., pieceWiseFunction.f(0.0));
		assertEquals(5., pieceWiseFunction.f(10.0));
		assertEquals(5., pieceWiseFunction.f(50000.0));
		assertEquals(5., pieceWiseFunction.f(1e20));
		
		pieceWiseFunction.addFunction(50., new ConstantFunction(8));
		assertEquals(5., pieceWiseFunction.f(0.));
		assertEquals(5., pieceWiseFunction.f(10.));
		assertEquals(8., pieceWiseFunction.f(50.));
		assertEquals(8., pieceWiseFunction.f(100.));
		assertEquals(8., pieceWiseFunction.f(1e5));
		
		pieceWiseFunction.addFunction(300., new ConstantFunction(20));
		assertEquals(5., pieceWiseFunction.f(0.));
		assertEquals(8., pieceWiseFunction.f(50.));
		assertEquals(8., pieceWiseFunction.f(200.));
		assertEquals(20., pieceWiseFunction.f(300.));
		assertEquals(20., pieceWiseFunction.f(1e5));		
		
		pieceWiseFunction.addFunction(100., new ConstantFunction(10));
		assertEquals(5., pieceWiseFunction.f(0.));
		assertEquals(8., pieceWiseFunction.f(50.));
		assertEquals(8., pieceWiseFunction.f(80.));
		assertEquals(10., pieceWiseFunction.f(100.));
		assertEquals(10., pieceWiseFunction.f(200.));
		assertEquals(20., pieceWiseFunction.f(300.));
		assertEquals(20., pieceWiseFunction.f(1e5));
		
		pieceWiseFunction.addFunction(20., new ConstantFunction(6));
		assertEquals(5., pieceWiseFunction.f(0.));
		assertEquals(5., pieceWiseFunction.f(5.));
		assertEquals(6., pieceWiseFunction.f(20.));
		assertEquals(6., pieceWiseFunction.f(30.));
		assertEquals(8., pieceWiseFunction.f(50.));
		assertEquals(8., pieceWiseFunction.f(80.));
		assertEquals(10., pieceWiseFunction.f(100.));
		assertEquals(10., pieceWiseFunction.f(200.));
		assertEquals(20., pieceWiseFunction.f(300.));
		assertEquals(20., pieceWiseFunction.f(1e5));
		
		//add a new function at the same time as an already present function
		pieceWiseFunction.addFunction(100., new ConstantFunction(15));
		//the function should be added after the old function and the newly added function should be used when calling f(x)
		assertEquals(5., pieceWiseFunction.f(0.));
		assertEquals(5., pieceWiseFunction.f(5.));
		assertEquals(6., pieceWiseFunction.f(20.));
		assertEquals(6., pieceWiseFunction.f(30.));
		assertEquals(8., pieceWiseFunction.f(50.));
		assertEquals(8., pieceWiseFunction.f(80.));
		assertEquals(15., pieceWiseFunction.f(100.));
		assertEquals(15., pieceWiseFunction.f(200.));
		assertEquals(20., pieceWiseFunction.f(300.));
		assertEquals(20., pieceWiseFunction.f(1e5));
		
		pieceWiseFunction = new PiecewiseGrowthFunction(50., new ConstantFunction(5));
		try {
			pieceWiseFunction.f(10);
			fail("An exception should have been thrown, since time < creation time.");
		} catch (IllegalArgumentException e) {
			// we are supposed t be here
		}
		
		try {
			pieceWiseFunction.addFunction(50, new ConstantFunction());
			fail("An exception should have been thrown, since time == creation time.");
		} catch (IllegalArgumentException e) {
			// we are supposed t be here
		}
		
		try {
			pieceWiseFunction.addFunction(54, null);
			fail("An exception should have been thrown, since function == null.");
		} catch (IllegalArgumentException e) {
			// we are supposed t be here
		}
		
	}
	
	public void testCurrentValidFunctionAndTime() throws NoNextSectionException{
		PiecewiseGrowthFunction function = new PiecewiseGrowthFunction(10., new ConstantFunction(1));
		function.addFunction(20, new ConstantFunction(2));
		function.addFunction(30, new ConstantFunction(3));
		function.addFunction(40, new ConstantFunction(4));
		function.addFunction(50, new ConstantFunction(5));
		function.addFunction(60, new ConstantFunction(6));
		
		assertEquals(new ConstantFunction(3), function.getCurrentValidFunction(30));
		assertEquals(new ConstantFunction(3), function.getCurrentValidFunction(35));
		assertEquals(30., function.getTimeOfCurrentValidSection(30));
		assertEquals(30., function.getTimeOfCurrentValidSection(35));
		
		assertEquals(new ConstantFunction(6), function.getCurrentValidFunction(60));
		assertEquals(new ConstantFunction(6), function.getCurrentValidFunction(1234));
		assertEquals(60., function.getTimeOfCurrentValidSection(60));
		assertEquals(60., function.getTimeOfCurrentValidSection(1234));
		
		assertEquals(new ConstantFunction(1), function.getCurrentValidFunction(10));
		assertEquals(new ConstantFunction(1), function.getCurrentValidFunction(19.5));
		assertEquals(10., function.getTimeOfCurrentValidSection(10));
		assertEquals(10., function.getTimeOfCurrentValidSection(19.5));
		
		try {
			function.getCurrentValidFunction(0);
			fail("An exception should have been thrown.");
		} catch (IllegalArgumentException e) {
			assertEquals("There is no current valid section at the time 0.0. The first section becomes valid at time 10.0.", e.getMessage());
		}
	}
	
	public void testGetTimeOfNextValidFunction() throws NoNextSectionException{
		PiecewiseGrowthFunction function = new PiecewiseGrowthFunction(10., new ConstantFunction(1));
		function.addFunction(20, new ConstantFunction(2));
		function.addFunction(30, new ConstantFunction(3));
		function.addFunction(40, new ConstantFunction(4));
		function.addFunction(50, new ConstantFunction(5));
		function.addFunction(60, new ConstantFunction(6));
		
		assertEquals(40., function.getTimeOfNextValidFunction(30));
		assertEquals(20., function.getTimeOfNextValidFunction(11));
		assertEquals(30., function.getTimeOfNextValidFunction(23));
		assertEquals(50., function.getTimeOfNextValidFunction(49));
		assertEquals(60., function.getTimeOfNextValidFunction(56));
		
		try {
			function.getTimeOfNextValidFunction(60);
			fail("An exception should have been thrown.");
		} catch (NoNextSectionException e) {
			assertEquals("No next section avaliable for the current section: Section [Time: 60.0, Function: ConstantFunction [returnValue=6.0]]", e.getMessage());
		}
		
		try {
			function.getCurrentValidFunction(0);
			fail("An exception should have been thrown.");
		} catch (IllegalArgumentException e) {
			assertEquals("There is no current valid section at the time 0.0. The first section becomes valid at time 10.0.", e.getMessage());
		}
	}
	
	public void testDeleteAllFollowingSections(){
		PiecewiseGrowthFunction function = new PiecewiseGrowthFunction(10., new ConstantFunction(1));
		function.addFunction(20, new ConstantFunction(2));
		function.addFunction(30, new ConstantFunction(3));
		function.addFunction(40, new ConstantFunction(4));
		function.addFunction(50, new ConstantFunction(5));
		function.addFunction(60, new ConstantFunction(6));
		
		assertEquals(1., function.f(12));
		assertEquals(2., function.f(22));
		assertEquals(3., function.f(32));
		assertEquals(4., function.f(42));
		assertEquals(5., function.f(52));
		assertEquals(6., function.f(62));
		assertEquals(6., function.f(72));
		assertEquals(6., function.f(222));
		
		function.deleteAllFollowingSections(35);
		assertEquals(1., function.f(12));
		assertEquals(2., function.f(22));
		assertEquals(3., function.f(32));
		assertEquals(3., function.f(42));
		assertEquals(3., function.f(52));
		assertEquals(3., function.f(62));
		assertEquals(3., function.f(72));
		assertEquals(3., function.f(222));
		
		function.deleteAllFollowingSections(25);
		assertEquals(1., function.f(12));
		assertEquals(2., function.f(22));
		assertEquals(2., function.f(32));
		assertEquals(2., function.f(42));
		assertEquals(2., function.f(52));
		assertEquals(2., function.f(62));
		assertEquals(2., function.f(72));
		assertEquals(2., function.f(222));
		
		try {
			function.getCurrentValidFunction(0);
			fail("An exception should have been thrown.");
		} catch (IllegalArgumentException e) {
			assertEquals("There is no current valid section at the time 0.0. The first section becomes valid at time 10.0.", e.getMessage());
		}
	}
	
	public void testF_FirstDerivation(){
		PiecewiseGrowthFunction pieceWiseFunction = new PiecewiseGrowthFunction(0., new LinearFunction(1, 1));
		pieceWiseFunction.addFunction(20., new LinearFunction(2, 20));
		pieceWiseFunction.addFunction(50., new LinearFunction(3, 30));
		pieceWiseFunction.addFunction(100., new LinearFunction(4, 40));
		pieceWiseFunction.addFunction(300., new LinearFunction(5, 50));
		pieceWiseFunction.addFunction(100., new LinearFunction(8, 80));
		
		assertEquals(1., pieceWiseFunction.f_FirstDerivation(0.));
		assertEquals(1., pieceWiseFunction.f_FirstDerivation(5.));
		assertEquals(2., pieceWiseFunction.f_FirstDerivation(20.));
		assertEquals(2., pieceWiseFunction.f_FirstDerivation(30.));
		assertEquals(3., pieceWiseFunction.f_FirstDerivation(50.));
		assertEquals(3., pieceWiseFunction.f_FirstDerivation(80.));
		assertEquals(8., pieceWiseFunction.f_FirstDerivation(100.));
		assertEquals(8., pieceWiseFunction.f_FirstDerivation(200.));
		assertEquals(5., pieceWiseFunction.f_FirstDerivation(300.));
		assertEquals(5., pieceWiseFunction.f_FirstDerivation(1e5));
	}
	
	public void testToString(){
		PiecewiseGrowthFunction pieceWiseFunction = new PiecewiseGrowthFunction(0., new ConstantFunction(5));		
		pieceWiseFunction.addFunction(50., new ConstantFunction(8));
		pieceWiseFunction.addFunction(300., new ConstantFunction(20));
		pieceWiseFunction.addFunction(100., new ConstantFunction(10));
		pieceWiseFunction.addFunction(20., new ConstantFunction(6));
		pieceWiseFunction.addFunction(100., new ConstantFunction(15));
		
		assertEquals("0.0: ConstantFunction [returnValue=5.0] - 20.0: ConstantFunction [returnValue=6.0] - "
				+ "50.0: ConstantFunction [returnValue=8.0] - 100.0: ConstantFunction [returnValue=10.0] - "
				+ "100.0: ConstantFunction [returnValue=15.0] - 300.0: ConstantFunction [returnValue=20.0] - ", 
				pieceWiseFunction.toString());
	}
	
	public void testEqualsAndHashcode(){
		PiecewiseGrowthFunction f1 = new PiecewiseGrowthFunction(0, new ConstantFunction());
		PiecewiseGrowthFunction f2 = new PiecewiseGrowthFunction(0, new ConstantFunction());
		
		assertTrue(f1.equals(f1));
		assertTrue(f1.hashCode() == f1.hashCode());
		assertTrue(f1.equals(f2));
		assertTrue(f1.hashCode() == f2.hashCode());
		
		assertFalse(f1.equals(null));
		assertFalse(f1.equals(new ConstantFunction()));
		assertFalse(f1.hashCode() == new ConstantFunction().hashCode());
		
		//time
		f2 = new PiecewiseGrowthFunction(5, new ConstantFunction());
		assertFalse(f1.equals(f2));
		assertFalse(f1.hashCode() == f2.hashCode());
		
		//function
		f2 = new PiecewiseGrowthFunction(0, new ConstantFunction(2));
		assertFalse(f1.equals(f2));
		assertFalse(f1.hashCode() == f2.hashCode());
		
		//other structure
		f2 = new PiecewiseGrowthFunction(0, new ConstantFunction());
		f2.addFunction(20, new ConstantFunction(5));
		assertFalse(f1.equals(f2));
		assertFalse(f1.hashCode() == f2.hashCode());
		
		f1 = new PiecewiseGrowthFunction(0, new ConstantFunction());
		f1.addFunction(5, new ConstantFunction(5));
		f2 = new PiecewiseGrowthFunction(0, new ConstantFunction());
		assertFalse(f1.equals(f2));
		assertFalse(f1.hashCode() == f2.hashCode());
		
		f2.addFunction(5, new ConstantFunction(6));
		assertFalse(f1.equals(f2));
		assertFalse(f1.hashCode() == f2.hashCode());
	}
}
