/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support.functions;

import de.fhstralsund.catsit.support.functions.BasicFunction;
import de.fhstralsund.catsit.support.functions.ConstantFunction;
import de.fhstralsund.catsit.support.functions.SurvivalRate;
import junit.framework.TestCase;

public class TestSurvivalRate extends TestCase {

	public void testF() {
		
		// ** data **
		double alpha = 5.;
		double beta = 4;
		BasicFunction function = new SurvivalRate(alpha, beta);
				
		//check if the function yields the correct values 
		for (int i = 0; i < 20000; i++) {
			double correctValue = Math.exp( -1. * alpha * i - (beta * (i*i)) );
			assertEquals("at step "+i, correctValue, function.f(i));
		}
		
		alpha = 0.5;
		beta = 0.4;
		function = new SurvivalRate(alpha, beta);
				
		//check if the function yields the correct values 
		for (int i = 0; i < 20000; i++) {
			double correctValue = Math.exp( -1. * alpha * i - (beta * (i*i)) );
			assertEquals("at step "+i, correctValue, function.f(i));
		}

		alpha = 0.64;
		beta = 0.0004;
		function = new SurvivalRate(alpha, beta);
				
		//check if the function yields the correct values 
		for (int i = 0; i < 20000; i++) {
			double correctValue = Math.exp( -1. * alpha * i - (beta * (i*i)) );
			assertEquals("at step "+i, correctValue, function.f(i));
		}
	}
	
	public void testToString() {
		BasicFunction function = new SurvivalRate(1, 2);
		assertEquals("SurvivalRate [alpha=1.0, beta=2.0]", function.toString());
		
	}
	
	public void testEquals() {
		BasicFunction function = new SurvivalRate(0.5, 5);
		
		assertFalse(function.equals(null));
		assertFalse(function.equals(new ConstantFunction()));
		assertFalse(function.equals(new SurvivalRate(0.5, 7)));
		assertFalse(function.equals(new SurvivalRate(0.4, 5)));
		
		assertTrue(function.equals(function));
		assertTrue(function.equals(new SurvivalRate(0.5, 5)));
	}
	
	public void testHashCode() {
		BasicFunction function = new SurvivalRate(0.5, 5);
		
		assertFalse(function.hashCode() == new ConstantFunction().hashCode());
		assertFalse(function.hashCode() == new SurvivalRate(0.5, 7).hashCode());
		assertFalse(function.hashCode() == new SurvivalRate(0.4, 5).hashCode());
		
		assertTrue(function.hashCode() == function.hashCode());
		assertTrue(function.hashCode() == new SurvivalRate(0.5, 5).hashCode());
	}
}
