/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support.functions.chemo.derivations;

import junit.framework.TestCase;
import de.fhstralsund.catsit.support.functions.ConstantFunction;
import de.fhstralsund.catsit.support.functions.LinearFunction;
import de.fhstralsund.catsit.support.functions.PowerFunction;
import de.fhstralsund.catsit.support.functions.chemo.derivations.BasicChemoFunctionDerivation;

public class TestAbstractBasicChemoFunctionDerivation extends TestCase {

	
	public void testFindRoot(){
		//a constant function has no root
		BasicChemoFunctionDerivation function = new MockBasicChemoFunctionDerivation(new ConstantFunction(5), 1, 1, 1, 1, 0);		
		assertNull(function.findRoot(new ConstantFunction(), 0));
		
		//the linear function has its root at 0
		function = new MockBasicChemoFunctionDerivation(new LinearFunction(5, 0), 1, 1, 1, 1, 0);
		assertEquals(0.0, function.findRoot(new ConstantFunction(5), -2));
		assertEquals(0.0, function.findRoot(new ConstantFunction(5), 2));
		
		assertEquals(0.0, function.findRoot(new ConstantFunction(5), 100));
		
		//the quadratic function has its root at 0
		function = new MockBasicChemoFunctionDerivation(new PowerFunction(1, 2, 0), 1, 1, 1, 1, 0);
		assertEquals(0.0, function.findRoot(new LinearFunction(2, 0), -2), 1e10);
		assertEquals(0.0, function.findRoot(new LinearFunction(2, 0), 2), 1e10);
				
		assertEquals(0.0, function.findRoot(new LinearFunction(2, 0), 100), 1e10);
	}
}
