/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support.functions.dosimetry;

import de.fhstralsund.catsit.support.functions.dosimetry.MIRDMeanAbsorbedDose;
import junit.framework.TestCase;


public class TestMIRDMeanAbsorbedDose extends TestCase{

	public void testConstructor(){
		try {
			new MIRDMeanAbsorbedDose(0, 2, 3, 4);
			fail("An exception should have been thrown.");
		} catch (IllegalArgumentException e) {
			assertEquals("The activity must not be zero.", e.getMessage());
		}
		try {
			new MIRDMeanAbsorbedDose(-5, 2, 3, 4);
			fail("An exception should have been thrown.");
		} catch (IllegalArgumentException e) {
			assertEquals("The activity must not be zero.", e.getMessage());
		}
		
		try {
			new MIRDMeanAbsorbedDose(1, 2, 3, 0);
			fail("An exception should have been thrown.");
		} catch (IllegalArgumentException e) {
			assertEquals("The tissue mass must not be zero.", e.getMessage());
		}
		
		try {
			new MIRDMeanAbsorbedDose(1, 2, 3, -5);
			fail("An exception should have been thrown.");
		} catch (IllegalArgumentException e) {
			assertEquals("The tissue mass must not be zero.", e.getMessage());
		}
	}
	
	public void testValue(){
		MIRDMeanAbsorbedDose dose = new MIRDMeanAbsorbedDose(1, 2, 3, 4);		
		assertEquals(1.248184519, dose.getValue(), 1e-8);
		
		dose = new MIRDMeanAbsorbedDose(0.5, 0.4, 2, 300);		
		assertEquals(1.10949735e-3, dose.getValue(), 1e-8);
		
	}
}
