/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support.randoms;

import de.fhstralsund.catsit.support.randoms.RandomG;
import junit.framework.TestCase;

public class TestRandomG extends TestCase {
	
	public void testNormal() {
		RandomG randomG;
		randomG = RandomG.getInstance();
		
		long[] buckets = new long[100];	 // -5 .. 5
		int numberOfLoops = 10000000;
		
		for (int i=0; i<numberOfLoops; i++) {
			double rand = randomG.getNormal();			
			int index = (int) (50. + 10. * rand);
			if (index>99) index = 99;
			if (index<0) index = 0;
			buckets[index]++;
		}
		
		double normFactor = 1./Math.sqrt(2*Math.PI);
		for (int i=40; i<=60; i++){
			double x = ((double)i-50.)/10.;
			double expectedProbability = Math.exp(-0.5*x*x)*normFactor;
			// the factor 10. in the next equation is the inverse interval 0.1
			double isProbability = 10.*(double)buckets[i]/(double)numberOfLoops;
			assertEquals("at i=" +i, expectedProbability, isProbability, 0.015 );
		}
	}
}
