/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support.randoms;

import de.fhstralsund.catsit.support.randoms.Random16807;
import de.fhstralsund.catsit.support.randoms.RandomG;
import de.fhstralsund.catsit.support.randoms.RandomGException;
import junit.framework.TestCase;

public class TestRandomG16807 extends TestCase {
	private static final long NUMBER_TEST_ITERATIONS = 10000;
	private static final double DELTA = 0.03;


	
	public void testSetSeed(){
		@SuppressWarnings("unused")
		RandomG randomG;
		try {
			randomG = new Random16807(0);
			fail("exception expected but not thrown");
		} catch (RandomGException e) {
			// we expect to be here
		}
		try {
			randomG = new Random16807(-1L);
			fail("exception expected but not thrown");
		} catch (RandomGException e) {
			// we expect to be here
		}
	}
	
	public void testGetDouble() {
		RandomG randomG;
		randomG = new Random16807();
		
		double sum = 0;
		for (int i=0; i<NUMBER_TEST_ITERATIONS; i++) {
			double newDouble = randomG.getDouble();
			assertTrue(newDouble>=0);
			assertTrue(newDouble<=1);
			sum += newDouble;
		}
		
		assertEquals(0.5, sum/NUMBER_TEST_ITERATIONS, DELTA);
	}
	
	public void testNormal() {
		RandomG randomG;
		randomG = new Random16807();
		
		long[] buckets = new long[100];	 // -5 .. 5
		double sum = 0;
		int numberOfLoops = 10000000;
		
		for (int i=0; i<numberOfLoops; i++) {
			double rand = randomG.getNormal();
			sum+= rand;
			
			int index = (int) (50. + 10. * rand);
			if (index>99) index =99;
			if (index<0) index =0;
			buckets[index]++;
		}		
		
		double normFactor = 1./Math.sqrt(2*Math.PI);
		for (int i=41; i<=61; i++){
			double x = ((double)i-50.)/10.;
			double expectedProbability = Math.exp(-0.5*x*x)*normFactor;
			// the factor 10. in the next equation is the inverse interval 0.1
			double isProbability = 10.*(double)buckets[i]/(double)numberOfLoops;
			assertEquals("at i=" +i, expectedProbability, isProbability, 0.015 );
		}
	}
}
