/*
	--------------------------------------------------------------------------------
	CaTSiT - A simulation tool for metastatic progression and treatments
	--------------------------------------------------------------------------------
	
	Copyright (C) 2014  Gero Wedemann, Anja Bethge
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Contact: anja.bethge@fh-stralsund.de
	         gero.wedemann@fh-stralsund.de
	
	
	--------------------------------------------------------------------------------
	Installation and documentation 
	--------------------------------------------------------------------------------
	
	Please visit http://www.bioinformatics.fh-stralsund.de/catsit/ 
 */

package de.fhstralsund.catsit.support.randoms;

import de.fhstralsund.catsit.support.randoms.Random16807;
import de.fhstralsund.catsit.support.randoms.RandomG;
import de.fhstralsund.catsit.support.randoms.RandomMT;
import junit.framework.TestCase;

public class TestRandomMT extends TestCase {
	private static final long NUMBER_TEST_ITERATIONS = 100000000;
	private static final double DELTA = 0.01;
	
	public void testGetDouble() {
		RandomG randomG;
		randomG = new RandomMT();
		
		double max = 0.0;
		double min = 1.0;
		
		double sum = 0;
		for (int i=0; i<NUMBER_TEST_ITERATIONS; i++) {
			double newDouble = randomG.getDouble();
			assertTrue(newDouble>=0);
			assertTrue(newDouble<=1);
			sum += newDouble;
			
			if(newDouble > max) max = newDouble;
			if(newDouble < min) min = newDouble;
		}
		
		assertEquals(0.5, sum/NUMBER_TEST_ITERATIONS, DELTA);
	}
	
	public void testEquals(){
		RandomG randomG = new RandomMT();
		RandomG randomG2 = new RandomMT();
		
		assertTrue(randomG.equals(randomG));
		assertFalse(randomG.equals(null));
		assertFalse(randomG.equals(new Random16807()));
		//if started with the same seed, the class will return the same values
		assertTrue(randomG.equals(randomG2));
	}
}
